/* Copyright  Grzegorz Kraszewski
 *
 * $Id: polski.c,v 1.12 2012/01/08 00:45:02 tokai Exp $
 */

/// includes

#define __NOLIBBASE__
#define USE_INLINE_STDARG

#include <proto/exec.h>
#include <proto/dos.h>
#include <exec/resident.h>
#include <exec/libraries.h>
#include <clib/debug_protos.h>
#include <libraries/locale.h>
#include <proto/locale.h>

#include "language.h"

#define LIBNAME "polski.language"
#define VERSION         51
#define REVISION        2
#define DATE    __AMIGADATE__
#define VERS    LIBNAME " 51.2"
#define VSTRING VERS " (" DATE ")  2005-"__COPYRIGHTYEAR__" Grzegorz Kraszewski\r\n"
#define VERSTAG "\0$VER: " VSTRING

///
/// basic defs and structures

struct LanguageBase
{
	struct Library          LibNode;
	APTR                    Seglist;
	struct SignalSemaphore  SemLock;	
};

struct Library *SysBase;
struct LocaleBase *LocaleBase;

static const CONST_WSTRPTR PolishStringsU[];
static const STRPTR PolishStrings[];
static const UBYTE PolishToLower[];
static const UBYTE PolishToUpper[];
static const UWORD PolishCTypes[];
static const UBYTE PolishCollate1[];
static const UBYTE PolishCollate2[];

#define MKBYTE(c,b) (((c) & ~0xFF) | (b))
#define MKBOOL(c,b) (((c) & ~0xFF) | ((b) ? 0xFF : 0))

///
/// protos

/* standards */

struct Library *LibInit(struct Library *unused, APTR seglist, struct Library *sysb);
struct LanguageBase *lib_init(struct LanguageBase *cb, APTR seglist, struct Library *SysBase);
APTR lib_expunge(struct LanguageBase *cb);
struct Library *LibOpen(void);
ULONG LibClose(void);
APTR LibExpunge(void);
ULONG LibReserved(void);
LONG dummy_function(void);
BOOL InitResources(struct LanguageBase *cb);
void FreeResources(struct LanguageBase *cb);

/* specific */

ULONG LibLanguageMask(void);
STRPTR LibGetLangString(void);
ULONG LibConvToLower(void);
ULONG LibConvToUpper(void);
ULONG LibIsAlnum(void);
ULONG LibIsAlpha(void);
ULONG LibIsCntrl(void);
ULONG LibIsDigit(void);
ULONG LibIsGraph(void);
ULONG LibIsLower(void);
ULONG LibIsPrint(void);
ULONG LibIsPunct(void);
ULONG LibIsSpace(void);
ULONG LibIsUpper(void);
ULONG LibIsXDigit(void);
LONG LibStrCompare(void);
CONST_WSTRPTR LibGetLangStringU(ULONG id, struct LocaleBase *LocaleBase);

///
/// dummy_function()

LONG dummy_function(void)
  {
    return -1;
  }

///
/// resident

const UBYTE LibName[] = LIBNAME;
const UBYTE VTag[] = VERSTAG;

const struct Resident __attribute__((section(".text"))) ROMTag =
  {
    RTC_MATCHWORD,
    (APTR)&ROMTag,
    (APTR)&ROMTag + 1,
    RTF_EXTENDED | RTF_PPC,
    VERSION,
    NT_LIBRARY,
    -120,
    (STRPTR)LibName,
    VSTRING,
    (APTR)LibInit
    ,REVISION,
    NULL
  };

const CONST_APTR JumpTable[] =
  {
    (CONST_APTR) FUNCARRAY_BEGIN,
    (APTR)FUNCARRAY_32BIT_NATIVE,
    (APTR)LibOpen,
    (APTR)LibClose,
    (APTR)LibExpunge,
    (APTR)LibReserved,
    (APTR)LibLanguageMask,
    (APTR)LibConvToLower,
    (APTR)LibConvToUpper,
    (APTR)LibReserved,      // Private2 (Undocumented? Reserved?)
    (APTR)LibGetLangString,
    (APTR)LibIsAlnum,
    (APTR)LibIsAlpha,
    (APTR)LibIsCntrl,
    (APTR)LibIsDigit,
    (APTR)LibIsGraph,
    (APTR)LibIsLower,
    (APTR)LibIsPrint,
    (APTR)LibIsPunct,
    (APTR)LibIsSpace,
    (APTR)LibIsUpper,
    (APTR)LibIsXDigit,
    (APTR)LibReserved,      // for StrConvert
    (APTR)LibStrCompare,
    (APTR)0xFFFFFFFF,

    /* 17 */
    (APTR) FUNCARRAY_32BIT_SYSTEMV,
    &LibGetLangStringU,
    (APTR)-1L,

    (CONST_APTR) FUNCARRAY_END
  };

///
/// InitResources()

BOOL InitResources(struct LanguageBase *cb)
{
  return TRUE;
}

///
/// FreeResources()

void FreeResources(struct LanguageBase *cb)
{
  return;
}

///
/// LibInit()

struct LanguageBase *lib_init(struct LanguageBase *cb, APTR seglist, struct Library *sysbase)
{
  sysbase = sysbase;            // Suppresses "unused variable" warning.
  cb->Seglist = seglist;
  
  InitSemaphore(&cb->SemLock);
  
  return cb;
}

struct Library *LibInit(struct Library *unused, APTR seglist, struct Library *sysbase)
{
  unused = unused;      /* suppress warning */
  SysBase = sysbase;

  return (NewCreateLibraryTags(
   LIBTAG_FUNCTIONINIT, (ULONG)JumpTable,
   LIBTAG_LIBRARYINIT,  (ULONG)lib_init,
   LIBTAG_MACHINE,      MACHINE_PPC,
   LIBTAG_BASESIZE,     sizeof(struct LanguageBase),
   LIBTAG_SEGLIST,      (ULONG)seglist,
   LIBTAG_TYPE,         NT_LIBRARY,
   LIBTAG_PRI,          -120,
   LIBTAG_NAME,         (ULONG)ROMTag.rt_Name,
   LIBTAG_IDSTRING,     (ULONG)ROMTag.rt_IdString,
   LIBTAG_FLAGS,        LIBF_CHANGED | LIBF_SUMUSED,
   LIBTAG_VERSION,      VERSION,
   LIBTAG_REVISION,     REVISION,
   LIBTAG_PUBLIC,       TRUE,
  TAG_END));
}

///
/// LibOpen()

struct Library *LibOpen(void)
{
	struct LanguageBase *cb = (struct LanguageBase*)REG_A6;
	struct Library *lib = (struct Library*)cb;

	ObtainSemaphore(&cb->SemLock);
	if (!LocaleBase)
	{
		LocaleBase = (struct LocaleBase *)OpenLibrary("locale.library", 51);

		/* This library needs a function available since locale.library 51.18.
		 */
		if (!LIB_MINVER((struct Library*)LocaleBase, 51, 18))
		{
			CloseLibrary((struct Library*)LocaleBase);
			LocaleBase = NULL;
		}

		if (!LocaleBase)
			lib = NULL;
	}
	ReleaseSemaphore(&cb->SemLock);

#warning this is possibly unprotected, should move to start of function. In failure case decreased again.
	if (lib)
	{
		cb->LibNode.lib_Flags &= ~LIBF_DELEXP;
		cb->LibNode.lib_OpenCnt++;
	}


	return lib;
}

///
/// LibClose()

ULONG LibClose(void)
{
	struct LanguageBase *cb = (struct LanguageBase*)REG_A6;
	ULONG ret = 0;

	ObtainSemaphore(&cb->SemLock);
	if (--cb->LibNode.lib_OpenCnt == 0)
	{
		if(LocaleBase) CloseLibrary((struct Library *)LocaleBase);
		LocaleBase = NULL;
		if (cb->LibNode.lib_Flags & LIBF_DELEXP) ret = (ULONG)lib_expunge(cb);
	}
	ReleaseSemaphore(&cb->SemLock);

	return ret;
}

///
/// LibExpunge()

APTR LibExpunge(void)
{
  struct LanguageBase *cb = (struct LanguageBase*)REG_A6;

  return(lib_expunge(cb));
}


APTR lib_expunge(struct LanguageBase *cb)
{
  APTR seglist = NULL;

  if (cb->LibNode.lib_OpenCnt == 0)
  {
    REMOVE((struct Node*)cb);
    FreeResources(cb);
    seglist = cb->Seglist;
    FreeMem((UBYTE*)cb - cb->LibNode.lib_NegSize, cb->LibNode.lib_NegSize + cb->LibNode.lib_PosSize);
    cb = NULL;    /* freed memory, no more valid */
  }
  else cb->LibNode.lib_Flags |= LIBF_DELEXP;

  return seglist;
}

///
/// LibReserved()

ULONG LibReserved(void)
{
  return 0;
}

///
/// LibLanguageMask()

ULONG LibLanguageMask(void)
{
  return (LF_ConvToLower | LF_ConvToUpper | LF_GetLangStr | LF_IsAlNum |
   LF_IsAlpha | LF_IsCntrl | LF_IsDigit | LF_IsGraph | LF_IsLower |
   LF_IsPrint | LF_IsPunct | LF_IsSpace | LF_IsUpper | LF_IsXDigit |
   LF_ToUpper | LF_StringComp | LF_GetLangStrU);
}

///
/// LibGetLangStringU()

CONST_WSTRPTR LibGetLangStringU(ULONG id, struct LocaleBase *LocaleBase)
{
    if (id < MAXSTRMSG)
        return PolishStringsU[id];
    else
        return NULL;
}

///
/// LibGetLangString()

STRPTR LibGetLangString(void)
{
  ULONG id = REG_D0;

  if (id < MAXSTRMSG) return PolishStrings[id];
  else return NULL;
}

///
/// LibConvToLower()

ULONG LibConvToLower(void)
{
  ULONG chr = REG_D0;

  return MKBYTE(chr, PolishToLower[(UBYTE)chr]);
}

///
/// LibConvToUpper()

ULONG LibConvToUpper(void)
{
  ULONG chr = REG_D0;

  return MKBYTE(chr, PolishToUpper[(UBYTE)chr]);
}

///
/// LibIsAlnum()

ULONG LibIsAlnum(void)
{
  ULONG chr = REG_D0;

  return MKBOOL(chr, PolishCTypes[(UBYTE)chr] & iAlNum);
}

///
/// LibIsAlpha()

ULONG LibIsAlpha(void)
{
  ULONG chr = REG_D0;

  return MKBOOL(chr, PolishCTypes[(UBYTE)chr] & iAlpha);
}

///
/// LibIsCntrl()

ULONG LibIsCntrl(void)
{
  ULONG chr = REG_D0;

  return MKBOOL(chr, PolishCTypes[(UBYTE)chr] & iCntrl);
}

///
/// LibIsDigit()

ULONG LibIsDigit(void)
{
  ULONG chr = REG_D0;

  return MKBOOL(chr, PolishCTypes[(UBYTE)chr] & iDigit);
}

///
/// LibIsGraph()

ULONG LibIsGraph(void)
{
  ULONG chr = REG_D0;

  return MKBOOL(chr, PolishCTypes[(UBYTE)chr] & iGraph);
}

///
/// LibIsLower()

ULONG LibIsLower(void)
{
  ULONG chr = REG_D0;

  return MKBOOL(chr, PolishCTypes[(UBYTE)chr] & iLower);
}

///
/// LibIsPrint()

ULONG LibIsPrint(void)
{
  ULONG chr = REG_D0;

  return MKBOOL(chr, PolishCTypes[(UBYTE)chr] & iPrint);
}

///
/// LibIsPunct()

ULONG LibIsPunct(void)
{
  ULONG chr = REG_D0;

  return MKBOOL(chr, PolishCTypes[(UBYTE)chr] & iPunct);
}

///
/// LibIsSpace()

ULONG LibIsSpace(void)
{
  ULONG chr = REG_D0;

  return MKBOOL(chr, PolishCTypes[(UBYTE)chr] & iSpace);
}

///
/// LibIsUpper()

ULONG LibIsUpper(void)
{
  ULONG chr = REG_D0;

  return MKBOOL(chr, PolishCTypes[(UBYTE)chr] & iUpper);
}

///
/// LibIsXDigit()

ULONG LibIsXDigit(void)
{
  ULONG chr = REG_D0;

  return MKBOOL(chr, PolishCTypes[(UBYTE)chr] & iXDigit);
}

///
/// LibStrCompare()

LONG LibStrCompare(void)
{
  STRPTR string1 = (STRPTR)REG_A1;
  STRPTR string2 = (STRPTR)REG_A2;
  LONG length = REG_D0;
  ULONG type = REG_D1;

	CONST UBYTE *coll_tab;

	switch (type)
	{
		case SC_ASCII:    coll_tab = PolishToUpper; break;
		case SC_COLLATE1: coll_tab = PolishCollate1; break;
		case SC_COLLATE2: coll_tab = PolishCollate2; break;
		default:          return 0;
	}

	return StrCompareInternal(string1, string2, length, coll_tab, PolishCTypes);
}

///
/// PolishStringsU[]

// Strings with Polish diacritic characters have to be defined as ULONG tables:

STATIC CONST ULONG PolishMonday[] = {'p', 'o', 'n', 'i', 'e', 'd', 'z', 'i', 'a', 0x0142, 'e', 'k', 0x0000};
STATIC CONST ULONG PolishWednesday[] = {0x015b, 'r', 'o', 'd', 'a', 0x0000};
STATIC CONST ULONG PolishFriday[] = {'p', 'i', 0x0105, 't', 'e', 'k', 0x0000};
STATIC CONST ULONG PolishWe[] = {0x015a, 'r', 0x0000};
STATIC CONST ULONG PolishJanuary[] = {'s', 't', 'y', 'c', 'z', 'e', 0x0144, 0x0000};
STATIC CONST ULONG PolishApril[] = {'k', 'w', 'i', 'e', 'c', 'i', 'e', 0x0144, 0x0000};
STATIC CONST ULONG PolishAugust[] = {'s', 'i', 'e', 'r', 'p', 'i', 'e', 0x0144, 0x0000};
STATIC CONST ULONG PolishSeptember[] = {'w', 'r', 'z', 'e', 's', 'i', 'e', 0x0144, 0x0000};
STATIC CONST ULONG PolishOctober[] = {'p', 'a', 0x017a, 'd', 'z', 'i', 'e', 'r', 'n', 'i', 'k', 0x0000};
STATIC CONST ULONG PolishDecember[] = {'g', 'r', 'u', 'd', 'z', 'i', 'e', 0x0144, 0x0000};
STATIC CONST ULONG PolishOct[] = {'P', 'a', 0x017a, 0x0000};
STATIC CONST ULONG PolishPM[] = {'p', 'o', 0x00a0, 'p', 'o', 0x0142, '.', 0x0000};
STATIC CONST ULONG PolishOpenQuote[] = {0x201e, 0x0000};  // DOUBLE LOW-9 QUOTATION MARK
STATIC CONST ULONG PolishCloseQuote[] = {0x201d, 0x0000}; // RIGHT DOUBLE QUOTATION MARK
STATIC CONST ULONG PolishToday[] = {'d', 'z', 'i', 0x015b, 0x0000};
STATIC CONST ULONG PolishFuture[] = {'p', 'r', 'z', 'y', 's', 'z', 0x0142, 'o', 0x015b, 0x0107, 0x0000};


static const CONST_WSTRPTR PolishStringsU[] =
{
        /* A blank string */

        (CONST_WSTRPTR)L"",

        /*  The days of the week. Starts with the first day of the week.
                In English this would be Sunday, this depends upon the settings
                of Locale->CalendarType. */

				(CONST_WSTRPTR)L"niedziela", (CONST_WSTRPTR)PolishMonday, (CONST_WSTRPTR)L"wtorek", (CONST_WSTRPTR)PolishWednesday, (CONST_WSTRPTR)L"czwartek", (CONST_WSTRPTR)PolishFriday,
        (CONST_WSTRPTR)L"sobota",

        /* Abbreviated days of the week */

				(CONST_WSTRPTR)L"Nd", (CONST_WSTRPTR)L"Pn", (CONST_WSTRPTR)L"Wt", (CONST_WSTRPTR)PolishWe, (CONST_WSTRPTR)L"Cz", (CONST_WSTRPTR)L"Pt", (CONST_WSTRPTR)L"So",

        /* Months of the year */

				(CONST_WSTRPTR)PolishJanuary, (CONST_WSTRPTR)L"luty", (CONST_WSTRPTR)L"marzec", (CONST_WSTRPTR)PolishApril, (CONST_WSTRPTR)L"maj", (CONST_WSTRPTR)L"czerwiec",
				(CONST_WSTRPTR)L"lipiec", (CONST_WSTRPTR)PolishAugust, (CONST_WSTRPTR)PolishSeptember, (CONST_WSTRPTR)PolishOctober, (CONST_WSTRPTR)L"listopad", (CONST_WSTRPTR)PolishDecember,

        /* Abbreviated months of the year */

        (CONST_WSTRPTR)L"Sty", (CONST_WSTRPTR)L"Lut", (CONST_WSTRPTR)L"Mar", (CONST_WSTRPTR)L"Kwi", (CONST_WSTRPTR)L"Maj", (CONST_WSTRPTR)L"Cze",
				(CONST_WSTRPTR)L"Lip", (CONST_WSTRPTR)L"Sie", (CONST_WSTRPTR)L"Wrz", (CONST_WSTRPTR)PolishOct, (CONST_WSTRPTR)L"Lis", (CONST_WSTRPTR)L"Gru",

        (CONST_WSTRPTR)L"Tak", /* Yes, affirmative response */
        (CONST_WSTRPTR)L"Nie", /* No/negative response */

        /* AM/PM strings AM 0000 -> 1159, PM 1200 -> 2359 */

				(CONST_WSTRPTR)L"rano", (CONST_WSTRPTR)PolishPM,

        /* Soft and hard hyphens */

        (CONST_WSTRPTR)L"-", (CONST_WSTRPTR)L"-",

        /* Open and close quotes */

				(CONST_WSTRPTR)PolishOpenQuote, (CONST_WSTRPTR)PolishCloseQuote,

        /* Days: But not actual day names
           Yesterday - the day before the current
           Today - the current day
           Tomorrow - the next day
           Future.
        */

				(CONST_WSTRPTR)L"wczoraj", (CONST_WSTRPTR)PolishToday, (CONST_WSTRPTR)L"jutro", (CONST_WSTRPTR)PolishFuture
};

///
/// PolishStrings[]

static const STRPTR PolishStrings[] =
{
        /* A blank string */

        "",

        /*  The days of the week. Starts with the first day of the week.
                In English this would be Sunday, this depends upon the settings
                of Locale->CalendarType. */

        "niedziela", "poniedziaek", "wtorek", "roda", "czwartek", "pitek",
        "sobota",

        /* Abbreviated days of the week */

        "Nd", "Pn", "Wt", "r", "Cz", "Pt", "So",

        /* Months of the year */

        "stycze", "luty", "marzec", "kwiecie", "maj", "czerwiec",
        "lipiec", "sierpie", "wrzesie", "padziernik", "listopad", "grudzie",

        /* Abbreviated months of the year */

        "Sty", "Lut", "Mar", "Kwi", "Maj", "Cze",
        "Lip", "Sie", "Wrz", "Pa", "Lis", "Gru",

        "Tak", /* Yes, affirmative response */
        "Nie", /* No/negative response */

        /* AM/PM strings AM 0000 -> 1159, PM 1200 -> 2359 */

        "rano", "po po.",

        /* Soft and hard hyphens */

        "-", "-",

        /* Open and close quotes */

        "\"", "\"",

        /* Days: But not actual day names
           Yesterday - the day before the current
           Today - the current day
           Tomorrow - the next day
           Future.
        */

        "wczoraj", "dzi", "jutro", "przyszo"
};

///
/// PolishCTypes[]

static const UWORD PolishCTypes[256] =
{
  iCntrl, /* NULL */
  iCntrl, /* START OF HEADING */
  iCntrl, /* START OF TEXT */
  iCntrl, /* END OF TEXT */
  iCntrl, /* END OF TRANSMISSION */
  iCntrl, /* ENQUIRY */
  iCntrl, /* ACKNOWLEDGE */
  iCntrl, /* BELL */
  iCntrl | iPrint | iSpace, /* BACKSPACE */
  iCntrl | iPrint | iSpace, /* HORIZONTAL TABULATION */
  iCntrl | iPrint | iSpace, /* LINE FEED */
  iCntrl | iPrint | iSpace, /* VERTICAL TABULATION */
  iCntrl | iPrint | iSpace, /* FORM FEED */
  iCntrl | iPrint | iSpace, /* CARRIAGE RETURN */
  iCntrl, /* SHIFT OUT */
  iCntrl, /* SHIFT IN */
  iCntrl, /* DATA LINK ESCAPE */
  iCntrl, /* DEVICE CONTROL ONE */
  iCntrl, /* DEVICE CONTROL TWO */
  iCntrl, /* DEVICE CONTROL THREE */
  iCntrl, /* DEVICE CONTROL FOUR */
  iCntrl, /* NEGATIVE ACKNOWLEDGE */
  iCntrl, /* SYNCHRONOUS IDLE */
  iCntrl, /* END OF TRANSMISSION BLOCK */
  iCntrl, /* CANCEL */
  iCntrl, /* END OF MEDIUM */
  iCntrl, /* SUBSTITUTE */
  iCntrl, /* ESCAPE */
  iCntrl, /* FILE SEPARATOR */
  iCntrl, /* GROUP SEPARATOR */
  iCntrl, /* RECORD SEPARATOR */
  iCntrl, /* UNIT SEPARATOR */

  iPrint | iSpace, /* SPACE */
  iGraph | iPrint | iPunct, /* EXCLAMATION MARK */
  iGraph | iPrint | iPunct, /* QUOTATION MARK */
  iGraph | iPrint | iPunct, /* NUMBER SIGN */
  iGraph | iPrint | iPunct, /* DOLLAR SIGN */
  iGraph | iPrint | iPunct, /* PERCENT SIGN */
  iGraph | iPrint | iPunct, /* AMPERSAND */
  iGraph | iPrint | iPunct, /* APOSTROPHE */
  iGraph | iPrint | iPunct, /* LEFT PARENTHESIS */
  iGraph | iPrint | iPunct, /* RIGHT PARENTHESIS */
  iGraph | iPrint | iPunct, /* ASTERISK */
  iGraph | iPrint | iPunct, /* PLUS SIGN */
  iGraph | iPrint | iPunct, /* COMMA */
  iGraph | iPrint | iPunct, /* HYPHEN-MINUS */
  iGraph | iPrint | iPunct, /* FULL STOP */
  iGraph | iPrint | iPunct, /* SOLIDUS */
  iGraph | iPrint | iDigit | iXDigit, /* DIGIT ZERO */
  iGraph | iPrint | iDigit | iXDigit, /* DIGIT ONE */
  iGraph | iPrint | iDigit | iXDigit, /* DIGIT TWO */
  iGraph | iPrint | iDigit | iXDigit, /* DIGIT THREE */
  iGraph | iPrint | iDigit | iXDigit, /* DIGIT FOUR */
  iGraph | iPrint | iDigit | iXDigit, /* DIGIT FIVE */
  iGraph | iPrint | iDigit | iXDigit, /* DIGIT SIX */
  iGraph | iPrint | iDigit | iXDigit, /* DIGIT SEVEN */
  iGraph | iPrint | iDigit | iXDigit, /* DIGIT EIGHT */
  iGraph | iPrint | iDigit | iXDigit, /* DIGIT NINE */
  iGraph | iPrint | iPunct, /* COLON */
  iGraph | iPrint | iPunct, /* SEMICOLON */
  iGraph | iPrint | iPunct, /* LESS-THAN SIGN */
  iGraph | iPrint | iPunct, /* EQUALS SIGN */
  iGraph | iPrint | iPunct, /* GREATER-THAN SIGN */
  iGraph | iPrint | iPunct, /* QUESTION MARK */

  iGraph | iPrint | iPunct, /* COMMERCIAL AT */
  iAlpha | iGraph | iPrint | iUpper | iXDigit, /* LATIN CAPITAL LETTER A */
  iAlpha | iGraph | iPrint | iUpper | iXDigit, /* LATIN CAPITAL LETTER B */
  iAlpha | iGraph | iPrint | iUpper | iXDigit, /* LATIN CAPITAL LETTER C */
  iAlpha | iGraph | iPrint | iUpper | iXDigit, /* LATIN CAPITAL LETTER D */
  iAlpha | iGraph | iPrint | iUpper | iXDigit, /* LATIN CAPITAL LETTER E */
  iAlpha | iGraph | iPrint | iUpper | iXDigit, /* LATIN CAPITAL LETTER F */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER G */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER H */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER I */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER J */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER K */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER L */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER M */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER N */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER O */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER P */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER Q */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER R */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER S */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER T */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER U */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER V */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER W */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER X */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER Y */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER Z */
  iGraph | iPrint | iPunct, /* LEFT SQUARE BRACKET */
  iGraph | iPrint | iPunct, /* REVERSE SOLIDUS */
  iGraph | iPrint | iPunct, /* RIGHT SQUARE BRACKET */
  iGraph | iPrint | iPunct, /* CIRCUMFLEX ACCENT */
  iGraph | iPrint | iPunct, /* LOW LINE */

  iGraph | iPrint | iPunct, /* GRAVE ACCENT */
  iAlpha | iGraph | iLower | iPrint | iXDigit, /* LATIN SMALL LETTER A */
  iAlpha | iGraph | iLower | iPrint | iXDigit, /* LATIN SMALL LETTER B */
  iAlpha | iGraph | iLower | iPrint | iXDigit, /* LATIN SMALL LETTER C */
  iAlpha | iGraph | iLower | iPrint | iXDigit, /* LATIN SMALL LETTER D */
  iAlpha | iGraph | iLower | iPrint | iXDigit, /* LATIN SMALL LETTER E */
  iAlpha | iGraph | iLower | iPrint | iXDigit, /* LATIN SMALL LETTER F */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER G */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER H */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER I */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER J */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER K */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER L */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER M */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER N */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER O */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER P */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER Q */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER R */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER S */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER T */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER U */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER V */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER W */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER X */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER Y */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER Z */
  iGraph | iPrint | iPunct, /* LEFT CURLY BRACKET */
  iGraph | iPrint | iPunct, /* VERTICAL LINE */
  iGraph | iPrint | iPunct, /* RIGHT CURLY BRACKET */
  iGraph | iPrint | iPunct, /* TILDE */
  iCntrl, /* DELETE */

  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */
  iCntrl, /* <control> */

  iPrint | iPunct, /* NO-BREAK SPACE */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER A WITH OGONEK */
  iGraph | iPrint, /* BREVE */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER L WITH STROKE */
  iGraph | iPrint | iPunct, /* CURRENCY SIGN */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER L WITH CARON */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER S WITH ACUTE */
  iGraph | iPrint | iPunct, /* SECTION SIGN */
  iGraph | iPrint, /* DIAERESIS */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER S WITH CARON */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER S WITH CEDILLA */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER T WITH CARON */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER Z WITH ACUTE */
  iGraph | iPrint | iPunct, /* SOFT HYPHEN */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER Z WITH CARON */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER Z WITH DOT ABOVE */
  iGraph | iPrint | iPunct, /* DEGREE SIGN */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER A WITH OGONEK */
  iGraph | iPrint, /* OGONEK */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER L WITH STROKE */
  iGraph | iPrint, /* ACUTE ACCENT */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER L WITH CARON */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER S WITH ACUTE */
  iGraph | iPrint, /* CARON */
  iGraph | iPrint, /* CEDILLA */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER S WITH CARON */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER S WITH CEDILLA */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER T WITH CARON */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER Z WITH ACUTE */
  iGraph | iPrint, /* DOUBLE ACUTE ACCENT */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER Z WITH CARON */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER Z WITH DOT ABOVE */

  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER R WITH ACUTE */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER A WITH ACUTE */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER A WITH CIRCUMFLEX */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER A WITH BREVE */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER A WITH DIAERESIS */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER L WITH ACUTE */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER C WITH ACUTE */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER C WITH CEDILLA */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER C WITH CARON */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER E WITH ACUTE */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER E WITH OGONEK */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER E WITH DIAERESIS */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER E WITH CARON */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER I WITH ACUTE */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER I WITH CIRCUMFLEX */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER D WITH CARON */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER D WITH STROKE */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER N WITH ACUTE */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER N WITH CARON */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER O WITH ACUTE */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER O WITH CIRCUMFLEX */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER O WITH DOUBLE ACUTE */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER O WITH DIAERESIS */
  iGraph | iPrint | iPunct, /* MULTIPLICATION SIGN */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER R WITH CARON */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER U WITH RING ABOVE */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER U WITH ACUTE */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER U WITH DOUBLE ACUTE */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER U WITH DIAERESIS */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER Y WITH ACUTE */
  iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER T WITH CEDILLA */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER SHARP S */

  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER R WITH ACUTE */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER A WITH ACUTE */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER A WITH CIRCUMFLEX */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER A WITH BREVE */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER A WITH DIAERESIS */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER L WITH ACUTE */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER C WITH ACUTE */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER C WITH CEDILLA */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER C WITH CARON */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER E WITH ACUTE */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER E WITH OGONEK */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER E WITH DIAERESIS */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER E WITH CARON */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER I WITH ACUTE */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER I WITH CIRCUMFLEX */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER D WITH CARON */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER D WITH STROKE */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER N WITH ACUTE */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER N WITH CARON */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER O WITH ACUTE */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER O WITH CIRCUMFLEX */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER O WITH DOUBLE ACUTE */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER O WITH DIAERESIS */
  iGraph | iPrint | iPunct, /* DIVISION SIGN */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER R WITH CARON */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER U WITH RING ABOVE */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER U WITH ACUTE */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER U WITH DOUBLE ACUTE */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER U WITH DIAERESIS */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER Y WITH ACUTE */
  iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER T WITH CEDILLA */
  iGraph | iPrint, /* DOT ABOVE */
};

///
/// PolishToLower[]

// This table can be used without changes in all languages using ISO-8859-2
// encoding. [krashan]

static const UBYTE PolishToLower[256] =
{
  0x00, /* NULL */
  0x01, /* START OF HEADING */
  0x02, /* START OF TEXT */
  0x03, /* END OF TEXT */
  0x04, /* END OF TRANSMISSION */
  0x05, /* ENQUIRY */
  0x06, /* ACKNOWLEDGE */
  0x07, /* BELL */
  0x08, /* BACKSPACE */
  0x09, /* HORIZONTAL TABULATION */
  0x0A, /* LINE FEED */
  0x0B, /* VERTICAL TABULATION */
  0x0C, /* FORM FEED */
  0x0D, /* CARRIAGE RETURN */
  0x0E, /* SHIFT OUT */
  0x0F, /* SHIFT IN */
  0x10, /* DATA LINK ESCAPE */
  0x11, /* DEVICE CONTROL ONE */
  0x12, /* DEVICE CONTROL TWO */
  0x13, /* DEVICE CONTROL THREE */
  0x14, /* DEVICE CONTROL FOUR */
  0x15, /* NEGATIVE ACKNOWLEDGE */
  0x16, /* SYNCHRONOUS IDLE */
  0x17, /* END OF TRANSMISSION BLOCK */
  0x18, /* CANCEL */
  0x19, /* END OF MEDIUM */
  0x1A, /* SUBSTITUTE */
  0x1B, /* ESCAPE */
  0x1C, /* FILE SEPARATOR */
  0x1D, /* GROUP SEPARATOR */
  0x1E, /* RECORD SEPARATOR */
  0x1F, /* UNIT SEPARATOR */

  0x20, /* SPACE */
  0x21, /* EXCLAMATION MARK */
  0x22, /* QUOTATION MARK */
  0x23, /* NUMBER SIGN */
  0x24, /* DOLLAR SIGN */
  0x25, /* PERCENT SIGN */
  0x26, /* AMPERSAND */
  0x27, /* APOSTROPHE */
  0x28, /* LEFT PARENTHESIS */
  0x29, /* RIGHT PARENTHESIS */
  0x2A, /* ASTERISK */
  0x2B, /* PLUS SIGN */
  0x2C, /* COMMA */
  0x2D, /* HYPHEN-MINUS */
  0x2E, /* FULL STOP */
  0x2F, /* SOLIDUS */
  0x30, /* DIGIT ZERO */
  0x31, /* DIGIT ONE */
  0x32, /* DIGIT TWO */
  0x33, /* DIGIT THREE */
  0x34, /* DIGIT FOUR */
  0x35, /* DIGIT FIVE */
  0x36, /* DIGIT SIX */
  0x37, /* DIGIT SEVEN */
  0x38, /* DIGIT EIGHT */
  0x39, /* DIGIT NINE */
  0x3A, /* COLON */
  0x3B, /* SEMICOLON */
  0x3C, /* LESS-THAN SIGN */
  0x3D, /* EQUALS SIGN */
  0x3E, /* GREATER-THAN SIGN */
  0x3F, /* QUESTION MARK */

  0x40, /* COMMERCIAL AT */
  0x61, /* LATIN CAPITAL LETTER A */
  0x62, /* LATIN CAPITAL LETTER B */
  0x63, /* LATIN CAPITAL LETTER C */
  0x64, /* LATIN CAPITAL LETTER D */
  0x65, /* LATIN CAPITAL LETTER E */
  0x66, /* LATIN CAPITAL LETTER F */
  0x67, /* LATIN CAPITAL LETTER G */
  0x68, /* LATIN CAPITAL LETTER H */
  0x69, /* LATIN CAPITAL LETTER I */
  0x6A, /* LATIN CAPITAL LETTER J */
  0x6B, /* LATIN CAPITAL LETTER K */
  0x6C, /* LATIN CAPITAL LETTER L */
  0x6D, /* LATIN CAPITAL LETTER M */
  0x6E, /* LATIN CAPITAL LETTER N */
  0x6F, /* LATIN CAPITAL LETTER O */
  0x70, /* LATIN CAPITAL LETTER P */
  0x71, /* LATIN CAPITAL LETTER Q */
  0x72, /* LATIN CAPITAL LETTER R */
  0x73, /* LATIN CAPITAL LETTER S */
  0x74, /* LATIN CAPITAL LETTER T */
  0x75, /* LATIN CAPITAL LETTER U */
  0x76, /* LATIN CAPITAL LETTER V */
  0x77, /* LATIN CAPITAL LETTER W */
  0x78, /* LATIN CAPITAL LETTER X */
  0x79, /* LATIN CAPITAL LETTER Y */
  0x7A, /* LATIN CAPITAL LETTER Z */
  0x5B, /* LEFT SQUARE BRACKET */
  0x5C, /* REVERSE SOLIDUS */
  0x5D, /* RIGHT SQUARE BRACKET */
  0x5E, /* CIRCUMFLEX ACCENT */
  0x5F, /* LOW LINE */

  0x60, /* GRAVE ACCENT */
  0x61, /* LATIN SMALL LETTER A */
  0x62, /* LATIN SMALL LETTER B */
  0x63, /* LATIN SMALL LETTER C */
  0x64, /* LATIN SMALL LETTER D */
  0x65, /* LATIN SMALL LETTER E */
  0x66, /* LATIN SMALL LETTER F */
  0x67, /* LATIN SMALL LETTER G */
  0x68, /* LATIN SMALL LETTER H */
  0x69, /* LATIN SMALL LETTER I */
  0x6A, /* LATIN SMALL LETTER J */
  0x6B, /* LATIN SMALL LETTER K */
  0x6C, /* LATIN SMALL LETTER L */
  0x6D, /* LATIN SMALL LETTER M */
  0x6E, /* LATIN SMALL LETTER N */
  0x6F, /* LATIN SMALL LETTER O */
  0x70, /* LATIN SMALL LETTER P */
  0x71, /* LATIN SMALL LETTER Q */
  0x72, /* LATIN SMALL LETTER R */
  0x73, /* LATIN SMALL LETTER S */
  0x74, /* LATIN SMALL LETTER T */
  0x75, /* LATIN SMALL LETTER U */
  0x76, /* LATIN SMALL LETTER V */
  0x77, /* LATIN SMALL LETTER W */
  0x78, /* LATIN SMALL LETTER X */
  0x79, /* LATIN SMALL LETTER Y */
  0x7A, /* LATIN SMALL LETTER Z */
  0x7B, /* LEFT CURLY BRACKET */
  0x7C, /* VERTICAL LINE */
  0x7D, /* RIGHT CURLY BRACKET */
  0x7E, /* TILDE */
  0x7F, /* DELETE */

  0x80, /* <control> */
  0x81, /* <control> */
  0x82, /* <control> */
  0x83, /* <control> */
  0x84, /* <control> */
  0x85, /* <control> */
  0x86, /* <control> */
  0x87, /* <control> */
  0x88, /* <control> */
  0x89, /* <control> */
  0x8A, /* <control> */
  0x8B, /* <control> */
  0x8C, /* <control> */
  0x8D, /* <control> */
  0x8E, /* <control> */
  0x8F, /* <control> */
  0x90, /* <control> */
  0x91, /* <control> */
  0x92, /* <control> */
  0x93, /* <control> */
  0x94, /* <control> */
  0x95, /* <control> */
  0x96, /* <control> */
  0x97, /* <control> */
  0x98, /* <control> */
  0x99, /* <control> */
  0x9A, /* <control> */
  0x9B, /* <control> */
  0x9C, /* <control> */
  0x9D, /* <control> */
  0x9E, /* <control> */
  0x9F, /* <control> */

  0xA0, /* NO-BREAK SPACE */
  0xB1, /* LATIN CAPITAL LETTER A WITH OGONEK */
  0xA2, /* BREVE */
  0xB3, /* LATIN CAPITAL LETTER L WITH STROKE */
  0xA4, /* CURRENCY SIGN */
  0xB5, /* LATIN CAPITAL LETTER L WITH CARON */
  0xB6, /* LATIN CAPITAL LETTER S WITH ACUTE */
  0xA7, /* SECTION SIGN */
  0xA8, /* DIAERESIS */
  0xB9, /* LATIN CAPITAL LETTER S WITH CARON */
  0xBA, /* LATIN CAPITAL LETTER S WITH CEDILLA */
  0xBB, /* LATIN CAPITAL LETTER T WITH CARON */
  0xBC, /* LATIN CAPITAL LETTER Z WITH ACUTE */
  0xAD, /* SOFT HYPHEN */
  0xBE, /* LATIN CAPITAL LETTER Z WITH CARON */
  0xBF, /* LATIN CAPITAL LETTER Z WITH DOT ABOVE */
  0xB0, /* DEGREE SIGN */
  0xB1, /* LATIN SMALL LETTER A WITH OGONEK */
  0xB2, /* OGONEK */
  0xB3, /* LATIN SMALL LETTER L WITH STROKE */
  0xB4, /* ACUTE ACCENT */
  0xB5, /* LATIN SMALL LETTER L WITH CARON */
  0xB6, /* LATIN SMALL LETTER S WITH ACUTE */
  0xB7, /* CARON */
  0xB8, /* CEDILLA */
  0xB9, /* LATIN SMALL LETTER S WITH CARON */
  0xBA, /* LATIN SMALL LETTER S WITH CEDILLA */
  0xBB, /* LATIN SMALL LETTER T WITH CARON */
  0xBC, /* LATIN SMALL LETTER Z WITH ACUTE */
  0xBD, /* DOUBLE ACUTE ACCENT */
  0xBE, /* LATIN SMALL LETTER Z WITH CARON */
  0xBF, /* LATIN SMALL LETTER Z WITH DOT ABOVE */

  0xE0, /* LATIN CAPITAL LETTER R WITH ACUTE */
  0xE1, /* LATIN CAPITAL LETTER A WITH ACUTE */
  0xE2, /* LATIN CAPITAL LETTER A WITH CIRCUMFLEX */
  0xE3, /* LATIN CAPITAL LETTER A WITH BREVE */
  0xE4, /* LATIN CAPITAL LETTER A WITH DIAERESIS */
  0xE5, /* LATIN CAPITAL LETTER L WITH ACUTE */
  0xE6, /* LATIN CAPITAL LETTER C WITH ACUTE */
  0xE7, /* LATIN CAPITAL LETTER C WITH CEDILLA */
  0xE8, /* LATIN CAPITAL LETTER C WITH CARON */
  0xE9, /* LATIN CAPITAL LETTER E WITH ACUTE */
  0xEA, /* LATIN CAPITAL LETTER E WITH OGONEK */
  0xEB, /* LATIN CAPITAL LETTER E WITH DIAERESIS */
  0xEC, /* LATIN CAPITAL LETTER E WITH CARON */
  0xED, /* LATIN CAPITAL LETTER I WITH ACUTE */
  0xEE, /* LATIN CAPITAL LETTER I WITH CIRCUMFLEX */
  0xEF, /* LATIN CAPITAL LETTER D WITH CARON */
  0xF0, /* LATIN CAPITAL LETTER D WITH STROKE */
  0xF1, /* LATIN CAPITAL LETTER N WITH ACUTE */
  0xF2, /* LATIN CAPITAL LETTER N WITH CARON */
  0xF3, /* LATIN CAPITAL LETTER O WITH ACUTE */
  0xF4, /* LATIN CAPITAL LETTER O WITH CIRCUMFLEX */
  0xF5, /* LATIN CAPITAL LETTER O WITH DOUBLE ACUTE */
  0xF6, /* LATIN CAPITAL LETTER O WITH DIAERESIS */
  0xD7, /* MULTIPLICATION SIGN */
  0xF8, /* LATIN CAPITAL LETTER R WITH CARON */
  0xF9, /* LATIN CAPITAL LETTER U WITH RING ABOVE */
  0xFA, /* LATIN CAPITAL LETTER U WITH ACUTE */
  0xFB, /* LATIN CAPITAL LETTER U WITH DOUBLE ACUTE */
  0xFC, /* LATIN CAPITAL LETTER U WITH DIAERESIS */
  0xFD, /* LATIN CAPITAL LETTER Y WITH ACUTE */
  0xFE, /* LATIN CAPITAL LETTER T WITH CEDILLA */
  0xFF, /* LATIN SMALL LETTER SHARP S */

  0xE0, /* LATIN SMALL LETTER R WITH ACUTE */
  0xE1, /* LATIN SMALL LETTER A WITH ACUTE */
  0xE2, /* LATIN SMALL LETTER A WITH CIRCUMFLEX */
  0xE3, /* LATIN SMALL LETTER A WITH BREVE */
  0xE4, /* LATIN SMALL LETTER A WITH DIAERESIS */
  0xE5, /* LATIN SMALL LETTER L WITH ACUTE */
  0xE6, /* LATIN SMALL LETTER C WITH ACUTE */
  0xE7, /* LATIN SMALL LETTER C WITH CEDILLA */
  0xE8, /* LATIN SMALL LETTER C WITH CARON */
  0xE9, /* LATIN SMALL LETTER E WITH ACUTE */
  0xEA, /* LATIN SMALL LETTER E WITH OGONEK */
  0xEB, /* LATIN SMALL LETTER E WITH DIAERESIS */
  0xEC, /* LATIN SMALL LETTER E WITH CARON */
  0xED, /* LATIN SMALL LETTER I WITH ACUTE */
  0xEE, /* LATIN SMALL LETTER I WITH CIRCUMFLEX */
  0xEF, /* LATIN SMALL LETTER D WITH CARON */
  0xF0, /* LATIN SMALL LETTER D WITH STROKE */
  0xF1, /* LATIN SMALL LETTER N WITH ACUTE */
  0xF2, /* LATIN SMALL LETTER N WITH CARON */
  0xF3, /* LATIN SMALL LETTER O WITH ACUTE */
  0xF4, /* LATIN SMALL LETTER O WITH CIRCUMFLEX */
  0xF5, /* LATIN SMALL LETTER O WITH DOUBLE ACUTE */
  0xF6, /* LATIN SMALL LETTER O WITH DIAERESIS */
  0xF7, /* DIVISION SIGN */
  0xF8, /* LATIN SMALL LETTER R WITH CARON */
  0xF9, /* LATIN SMALL LETTER U WITH RING ABOVE */
  0xFA, /* LATIN SMALL LETTER U WITH ACUTE */
  0xFB, /* LATIN SMALL LETTER U WITH DOUBLE ACUTE */
  0xFC, /* LATIN SMALL LETTER U WITH DIAERESIS */
  0xFD, /* LATIN SMALL LETTER Y WITH ACUTE */
  0xFE, /* LATIN SMALL LETTER T WITH CEDILLA */
  0xFF  /* DOT ABOVE */
};

///
/// PolishToUpper[]

// This table can be used without changes in all languages using ISO-8859-2
// encoding. [krashan]

static const UBYTE PolishToUpper[256] =
{
  0x00, /* NULL */
  0x01, /* START OF HEADING */
  0x02, /* START OF TEXT */
  0x03, /* END OF TEXT */
  0x04, /* END OF TRANSMISSION */
  0x05, /* ENQUIRY */
  0x06, /* ACKNOWLEDGE */
  0x07, /* BELL */
  0x08, /* BACKSPACE */
  0x09, /* HORIZONTAL TABULATION */
  0x0A, /* LINE FEED */
  0x0B, /* VERTICAL TABULATION */
  0x0C, /* FORM FEED */
  0x0D, /* CARRIAGE RETURN */
  0x0E, /* SHIFT OUT */
  0x0F, /* SHIFT IN */
  0x10, /* DATA LINK ESCAPE */
  0x11, /* DEVICE CONTROL ONE */
  0x12, /* DEVICE CONTROL TWO */
  0x13, /* DEVICE CONTROL THREE */
  0x14, /* DEVICE CONTROL FOUR */
  0x15, /* NEGATIVE ACKNOWLEDGE */
  0x16, /* SYNCHRONOUS IDLE */
  0x17, /* END OF TRANSMISSION BLOCK */
  0x18, /* CANCEL */
  0x19, /* END OF MEDIUM */
  0x1A, /* SUBSTITUTE */
  0x1B, /* ESCAPE */
  0x1C, /* FILE SEPARATOR */
  0x1D, /* GROUP SEPARATOR */
  0x1E, /* RECORD SEPARATOR */
  0x1F, /* UNIT SEPARATOR */

  0x20, /* SPACE */
  0x21, /* EXCLAMATION MARK */
  0x22, /* QUOTATION MARK */
  0x23, /* NUMBER SIGN */
  0x24, /* DOLLAR SIGN */
  0x25, /* PERCENT SIGN */
  0x26, /* AMPERSAND */
  0x27, /* APOSTROPHE */
  0x28, /* LEFT PARENTHESIS */
  0x29, /* RIGHT PARENTHESIS */
  0x2A, /* ASTERISK */
  0x2B, /* PLUS SIGN */
  0x2C, /* COMMA */
  0x2D, /* HYPHEN-MINUS */
  0x2E, /* FULL STOP */
  0x2F, /* SOLIDUS */
  0x30, /* DIGIT ZERO */
  0x31, /* DIGIT ONE */
  0x32, /* DIGIT TWO */
  0x33, /* DIGIT THREE */
  0x34, /* DIGIT FOUR */
  0x35, /* DIGIT FIVE */
  0x36, /* DIGIT SIX */
  0x37, /* DIGIT SEVEN */
  0x38, /* DIGIT EIGHT */
  0x39, /* DIGIT NINE */
  0x3A, /* COLON */
  0x3B, /* SEMICOLON */
  0x3C, /* LESS-THAN SIGN */
  0x3D, /* EQUALS SIGN */
  0x3E, /* GREATER-THAN SIGN */
  0x3F, /* QUESTION MARK */

  0x40, /* COMMERCIAL AT */
  0x41, /* LATIN CAPITAL LETTER A */
  0x42, /* LATIN CAPITAL LETTER B */
  0x43, /* LATIN CAPITAL LETTER C */
  0x44, /* LATIN CAPITAL LETTER D */
  0x45, /* LATIN CAPITAL LETTER E */
  0x46, /* LATIN CAPITAL LETTER F */
  0x47, /* LATIN CAPITAL LETTER G */
  0x48, /* LATIN CAPITAL LETTER H */
  0x49, /* LATIN CAPITAL LETTER I */
  0x4A, /* LATIN CAPITAL LETTER J */
  0x4B, /* LATIN CAPITAL LETTER K */
  0x4C, /* LATIN CAPITAL LETTER L */
  0x4D, /* LATIN CAPITAL LETTER M */
  0x4E, /* LATIN CAPITAL LETTER N */
  0x4F, /* LATIN CAPITAL LETTER O */
  0x50, /* LATIN CAPITAL LETTER P */
  0x51, /* LATIN CAPITAL LETTER Q */
  0x52, /* LATIN CAPITAL LETTER R */
  0x53, /* LATIN CAPITAL LETTER S */
  0x54, /* LATIN CAPITAL LETTER T */
  0x55, /* LATIN CAPITAL LETTER U */
  0x56, /* LATIN CAPITAL LETTER V */
  0x57, /* LATIN CAPITAL LETTER W */
  0x58, /* LATIN CAPITAL LETTER X */
  0x59, /* LATIN CAPITAL LETTER Y */
  0x5A, /* LATIN CAPITAL LETTER Z */
  0x5B, /* LEFT SQUARE BRACKET */
  0x5C, /* REVERSE SOLIDUS */
  0x5D, /* RIGHT SQUARE BRACKET */
  0x5E, /* CIRCUMFLEX ACCENT */
  0x5F, /* LOW LINE */

  0x60, /* GRAVE ACCENT */
  0x41, /* LATIN SMALL LETTER A */
  0x42, /* LATIN SMALL LETTER B */
  0x43, /* LATIN SMALL LETTER C */
  0x44, /* LATIN SMALL LETTER D */
  0x45, /* LATIN SMALL LETTER E */
  0x46, /* LATIN SMALL LETTER F */
  0x47, /* LATIN SMALL LETTER G */
  0x48, /* LATIN SMALL LETTER H */
  0x49, /* LATIN SMALL LETTER I */
  0x4A, /* LATIN SMALL LETTER J */
  0x4B, /* LATIN SMALL LETTER K */
  0x4C, /* LATIN SMALL LETTER L */
  0x4D, /* LATIN SMALL LETTER M */
  0x4E, /* LATIN SMALL LETTER N */
  0x4F, /* LATIN SMALL LETTER O */
  0x50, /* LATIN SMALL LETTER P */
  0x51, /* LATIN SMALL LETTER Q */
  0x52, /* LATIN SMALL LETTER R */
  0x53, /* LATIN SMALL LETTER S */
  0x54, /* LATIN SMALL LETTER T */
  0x55, /* LATIN SMALL LETTER U */
  0x56, /* LATIN SMALL LETTER V */
  0x57, /* LATIN SMALL LETTER W */
  0x58, /* LATIN SMALL LETTER X */
  0x59, /* LATIN SMALL LETTER Y */
  0x5A, /* LATIN SMALL LETTER Z */
  0x7B, /* LEFT CURLY BRACKET */
  0x7C, /* VERTICAL LINE */
  0x7D, /* RIGHT CURLY BRACKET */
  0x7E, /* TILDE */
  0x7F, /* DELETE */

  0x80, /* <control> */
  0x81, /* <control> */
  0x82, /* <control> */
  0x83, /* <control> */
  0x84, /* <control> */
  0x85, /* <control> */
  0x86, /* <control> */
  0x87, /* <control> */
  0x88, /* <control> */
  0x89, /* <control> */
  0x8A, /* <control> */
  0x8B, /* <control> */
  0x8C, /* <control> */
  0x8D, /* <control> */
  0x8E, /* <control> */
  0x8F, /* <control> */
  0x90, /* <control> */
  0x91, /* <control> */
  0x92, /* <control> */
  0x93, /* <control> */
  0x94, /* <control> */
  0x95, /* <control> */
  0x96, /* <control> */
  0x97, /* <control> */
  0x98, /* <control> */
  0x99, /* <control> */
  0x9A, /* <control> */
  0x9B, /* <control> */
  0x9C, /* <control> */
  0x9D, /* <control> */
  0x9E, /* <control> */
  0x9F, /* <control> */

  0xA0, /* NO-BREAK SPACE */
  0xA1, /* LATIN CAPITAL LETTER A WITH OGONEK */
  0xA2, /* BREVE */
  0xA3, /* LATIN CAPITAL LETTER L WITH STROKE */
  0xA4, /* CURRENCY SIGN */
  0xA5, /* LATIN CAPITAL LETTER L WITH CARON */
  0xA6, /* LATIN CAPITAL LETTER S WITH ACUTE */
  0xA7, /* SECTION SIGN */
  0xA8, /* DIAERESIS */
  0xA9, /* LATIN CAPITAL LETTER S WITH CARON */
  0xAA, /* LATIN CAPITAL LETTER S WITH CEDILLA */
  0xAB, /* LATIN CAPITAL LETTER T WITH CARON */
  0xAC, /* LATIN CAPITAL LETTER Z WITH ACUTE */
  0xAD, /* SOFT HYPHEN */
  0xAE, /* LATIN CAPITAL LETTER Z WITH CARON */
  0xAF, /* LATIN CAPITAL LETTER Z WITH DOT ABOVE */
  0xB0, /* DEGREE SIGN */
  0xA1, /* LATIN SMALL LETTER A WITH OGONEK */
  0xB2, /* OGONEK */
  0xA3, /* LATIN SMALL LETTER L WITH STROKE */
  0xB4, /* ACUTE ACCENT */
  0xA5, /* LATIN SMALL LETTER L WITH CARON */
  0xA6, /* LATIN SMALL LETTER S WITH ACUTE */
  0xB7, /* CARON */
  0xB8, /* CEDILLA */
  0xA9, /* LATIN SMALL LETTER S WITH CARON */
  0xAA, /* LATIN SMALL LETTER S WITH CEDILLA */
  0xAB, /* LATIN SMALL LETTER T WITH CARON */
  0xAC, /* LATIN SMALL LETTER Z WITH ACUTE */
  0xBD, /* DOUBLE ACUTE ACCENT */
  0xAE, /* LATIN SMALL LETTER Z WITH CARON */
  0xAF, /* LATIN SMALL LETTER Z WITH DOT ABOVE */

  0xC0, /* LATIN CAPITAL LETTER R WITH ACUTE */
  0xC1, /* LATIN CAPITAL LETTER A WITH ACUTE */
  0xC2, /* LATIN CAPITAL LETTER A WITH CIRCUMFLEX */
  0xC3, /* LATIN CAPITAL LETTER A WITH BREVE */
  0xC4, /* LATIN CAPITAL LETTER A WITH DIAERESIS */
  0xC5, /* LATIN CAPITAL LETTER L WITH ACUTE */
  0xC6, /* LATIN CAPITAL LETTER C WITH ACUTE */
  0xC7, /* LATIN CAPITAL LETTER C WITH CEDILLA */
  0xC8, /* LATIN CAPITAL LETTER C WITH CARON */
  0xC9, /* LATIN CAPITAL LETTER E WITH ACUTE */
  0xCA, /* LATIN CAPITAL LETTER E WITH OGONEK */
  0xCB, /* LATIN CAPITAL LETTER E WITH DIAERESIS */
  0xCC, /* LATIN CAPITAL LETTER E WITH CARON */
  0xCD, /* LATIN CAPITAL LETTER I WITH ACUTE */
  0xCE, /* LATIN CAPITAL LETTER I WITH CIRCUMFLEX */
  0xCF, /* LATIN CAPITAL LETTER D WITH CARON */
  0xD0, /* LATIN CAPITAL LETTER D WITH STROKE */
  0xD1, /* LATIN CAPITAL LETTER N WITH ACUTE */
  0xD2, /* LATIN CAPITAL LETTER N WITH CARON */
  0xD3, /* LATIN CAPITAL LETTER O WITH ACUTE */
  0xD4, /* LATIN CAPITAL LETTER O WITH CIRCUMFLEX */
  0xD5, /* LATIN CAPITAL LETTER O WITH DOUBLE ACUTE */
  0xD6, /* LATIN CAPITAL LETTER O WITH DIAERESIS */
  0xD7, /* MULTIPLICATION SIGN */
  0xD8, /* LATIN CAPITAL LETTER R WITH CARON */
  0xD9, /* LATIN CAPITAL LETTER U WITH RING ABOVE */
  0xDA, /* LATIN CAPITAL LETTER U WITH ACUTE */
  0xDB, /* LATIN CAPITAL LETTER U WITH DOUBLE ACUTE */
  0xDC, /* LATIN CAPITAL LETTER U WITH DIAERESIS */
  0xDD, /* LATIN CAPITAL LETTER Y WITH ACUTE */
  0xDE, /* LATIN CAPITAL LETTER T WITH CEDILLA */
  0xDF, /* LATIN SMALL LETTER SHARP S */

  0xC0, /* LATIN SMALL LETTER R WITH ACUTE */
  0xC1, /* LATIN SMALL LETTER A WITH ACUTE */
  0xC2, /* LATIN SMALL LETTER A WITH CIRCUMFLEX */
  0xC3, /* LATIN SMALL LETTER A WITH BREVE */
  0xC4, /* LATIN SMALL LETTER A WITH DIAERESIS */
  0xC5, /* LATIN SMALL LETTER L WITH ACUTE */
  0xC6, /* LATIN SMALL LETTER C WITH ACUTE */
  0xC7, /* LATIN SMALL LETTER C WITH CEDILLA */
  0xC8, /* LATIN SMALL LETTER C WITH CARON */
  0xC9, /* LATIN SMALL LETTER E WITH ACUTE */
  0xCA, /* LATIN SMALL LETTER E WITH OGONEK */
  0xCB, /* LATIN SMALL LETTER E WITH DIAERESIS */
  0xCC, /* LATIN SMALL LETTER E WITH CARON */
  0xCD, /* LATIN SMALL LETTER I WITH ACUTE */
  0xCE, /* LATIN SMALL LETTER I WITH CIRCUMFLEX */
  0xCF, /* LATIN SMALL LETTER D WITH CARON */
  0xD0, /* LATIN SMALL LETTER D WITH STROKE */
  0xD1, /* LATIN SMALL LETTER N WITH ACUTE */
  0xD2, /* LATIN SMALL LETTER N WITH CARON */
  0xD3, /* LATIN SMALL LETTER O WITH ACUTE */
  0xD4, /* LATIN SMALL LETTER O WITH CIRCUMFLEX */
  0xD5, /* LATIN SMALL LETTER O WITH DOUBLE ACUTE */
  0xD6, /* LATIN SMALL LETTER O WITH DIAERESIS */
  0xF7, /* DIVISION SIGN */
  0xD8, /* LATIN SMALL LETTER R WITH CARON */
  0xD9, /* LATIN SMALL LETTER U WITH RING ABOVE */
  0xDA, /* LATIN SMALL LETTER U WITH ACUTE */
  0xDB, /* LATIN SMALL LETTER U WITH DOUBLE ACUTE */
  0xDC, /* LATIN SMALL LETTER U WITH DIAERESIS */
  0xDD, /* LATIN SMALL LETTER Y WITH ACUTE */
  0xDE, /* LATIN SMALL LETTER T WITH CEDILLA */
  0xFF  /* DOT ABOVE */
};

///
/// PolishCollate1[]

// This table SHOULD BE REVISED before using for other languages using
// ISO-8859-2 encoding. I assumed here all accented character have ordinals
// equal to non-accented version, it is true for Polish but need not to be
// true for other languages. [krashan]

const UBYTE PolishCollate1[256] =
{
  0x00, /* NULL */
  0x01, /* START OF HEADING */
  0x02, /* START OF TEXT */
  0x03, /* END OF TEXT */
  0x04, /* END OF TRANSMISSION */
  0x05, /* ENQUIRY */
  0x06, /* ACKNOWLEDGE */
  0x07, /* BELL */
  0x08, /* BACKSPACE */
  0x09, /* HORIZONTAL TABULATION */
  0x0A, /* LINE FEED */
  0x0B, /* VERTICAL TABULATION */
  0x0C, /* FORM FEED */
  0x0D, /* CARRIAGE RETURN */
  0x0E, /* SHIFT OUT */
  0x0F, /* SHIFT IN */
  0x10, /* DATA LINK ESCAPE */
  0x11, /* DEVICE CONTROL ONE */
  0x12, /* DEVICE CONTROL TWO */
  0x13, /* DEVICE CONTROL THREE */
  0x14, /* DEVICE CONTROL FOUR */
  0x15, /* NEGATIVE ACKNOWLEDGE */
  0x16, /* SYNCHRONOUS IDLE */
  0x17, /* END OF TRANSMISSION BLOCK */
  0x18, /* CANCEL */
  0x19, /* END OF MEDIUM */
  0x1A, /* SUBSTITUTE */
  0x1B, /* ESCAPE */
  0x1C, /* FILE SEPARATOR */
  0x1D, /* GROUP SEPARATOR */
  0x1E, /* RECORD SEPARATOR */
  0x1F, /* UNIT SEPARATOR */

  0x20, /* SPACE */
  0x21, /* EXCLAMATION MARK */
  0x22, /* QUOTATION MARK */
  0x23, /* NUMBER SIGN */
  0x24, /* DOLLAR SIGN */
  0x25, /* PERCENT SIGN */
  0x26, /* AMPERSAND */
  0x27, /* APOSTROPHE */
  0x28, /* LEFT PARENTHESIS */
  0x29, /* RIGHT PARENTHESIS */
  0x2A, /* ASTERISK */
  0x2B, /* PLUS SIGN */
  0x2C, /* COMMA */
  0x2D, /* HYPHEN-MINUS */
  0x2E, /* FULL STOP */
  0x2F, /* SOLIDUS */
  0x30, /* DIGIT ZERO */
  0x31, /* DIGIT ONE */
  0x32, /* DIGIT TWO */
  0x33, /* DIGIT THREE */
  0x34, /* DIGIT FOUR */
  0x35, /* DIGIT FIVE */
  0x36, /* DIGIT SIX */
  0x37, /* DIGIT SEVEN */
  0x38, /* DIGIT EIGHT */
  0x39, /* DIGIT NINE */
  0x3A, /* COLON */
  0x3B, /* SEMICOLON */
  0x3C, /* LESS-THAN SIGN */
  0x3D, /* EQUALS SIGN */
  0x3E, /* GREATER-THAN SIGN */
  0x3F, /* QUESTION MARK */

  0x40, /* COMMERCIAL AT */
  0x41, /* LATIN CAPITAL LETTER A */
  0x42, /* LATIN CAPITAL LETTER B */
  0x43, /* LATIN CAPITAL LETTER C */
  0x44, /* LATIN CAPITAL LETTER D */
  0x45, /* LATIN CAPITAL LETTER E */
  0x46, /* LATIN CAPITAL LETTER F */
  0x47, /* LATIN CAPITAL LETTER G */
  0x48, /* LATIN CAPITAL LETTER H */
  0x49, /* LATIN CAPITAL LETTER I */
  0x4A, /* LATIN CAPITAL LETTER J */
  0x4B, /* LATIN CAPITAL LETTER K */
  0x4C, /* LATIN CAPITAL LETTER L */
  0x4D, /* LATIN CAPITAL LETTER M */
  0x4E, /* LATIN CAPITAL LETTER N */
  0x4F, /* LATIN CAPITAL LETTER O */
  0x50, /* LATIN CAPITAL LETTER P */
  0x51, /* LATIN CAPITAL LETTER Q */
  0x52, /* LATIN CAPITAL LETTER R */
  0x53, /* LATIN CAPITAL LETTER S */
  0x54, /* LATIN CAPITAL LETTER T */
  0x55, /* LATIN CAPITAL LETTER U */
  0x56, /* LATIN CAPITAL LETTER V */
  0x57, /* LATIN CAPITAL LETTER W */
  0x58, /* LATIN CAPITAL LETTER X */
  0x59, /* LATIN CAPITAL LETTER Y */
  0x5A, /* LATIN CAPITAL LETTER Z */
  0x5B, /* LEFT SQUARE BRACKET */
  0x5C, /* REVERSE SOLIDUS */
  0x5D, /* RIGHT SQUARE BRACKET */
  0x5E, /* CIRCUMFLEX ACCENT */
  0x5F, /* LOW LINE */

  0x60, /* GRAVE ACCENT */
  0x41, /* LATIN SMALL LETTER A */
  0x42, /* LATIN SMALL LETTER B */
  0x43, /* LATIN SMALL LETTER C */
  0x44, /* LATIN SMALL LETTER D */
  0x45, /* LATIN SMALL LETTER E */
  0x46, /* LATIN SMALL LETTER F */
  0x47, /* LATIN SMALL LETTER G */
  0x48, /* LATIN SMALL LETTER H */
  0x49, /* LATIN SMALL LETTER I */
  0x4A, /* LATIN SMALL LETTER J */
  0x4B, /* LATIN SMALL LETTER K */
  0x4C, /* LATIN SMALL LETTER L */
  0x4D, /* LATIN SMALL LETTER M */
  0x4E, /* LATIN SMALL LETTER N */
  0x4F, /* LATIN SMALL LETTER O */
  0x50, /* LATIN SMALL LETTER P */
  0x51, /* LATIN SMALL LETTER Q */
  0x52, /* LATIN SMALL LETTER R */
  0x53, /* LATIN SMALL LETTER S */
  0x54, /* LATIN SMALL LETTER T */
  0x55, /* LATIN SMALL LETTER U */
  0x56, /* LATIN SMALL LETTER V */
  0x57, /* LATIN SMALL LETTER W */
  0x58, /* LATIN SMALL LETTER X */
  0x59, /* LATIN SMALL LETTER Y */
  0x5A, /* LATIN SMALL LETTER Z */
  0x61, /* LEFT CURLY BRACKET */
  0x62, /* VERTICAL LINE */
  0x63, /* RIGHT CURLY BRACKET */
  0x64, /* TILDE */
  0x65, /* DELETE */

  0x80, /* <control> */
  0x81, /* <control> */
  0x82, /* <control> */
  0x83, /* <control> */
  0x84, /* <control> */
  0x85, /* <control> */
  0x86, /* <control> */
  0x87, /* <control> */
  0x88, /* <control> */
  0x89, /* <control> */
  0x8A, /* <control> */
  0x8B, /* <control> */
  0x8C, /* <control> */
  0x8D, /* <control> */
  0x8E, /* <control> */
  0x8F, /* <control> */
  0x90, /* <control> */
  0x91, /* <control> */
  0x92, /* <control> */
  0x93, /* <control> */
  0x94, /* <control> */
  0x95, /* <control> */
  0x96, /* <control> */
  0x97, /* <control> */
  0x98, /* <control> */
  0x99, /* <control> */
  0x9A, /* <control> */
  0x9B, /* <control> */
  0x9C, /* <control> */
  0x9D, /* <control> */
  0x9E, /* <control> */
  0x9F, /* <control> */

  0x20, /* NO-BREAK SPACE */ /* I think leaving the value 160 for this is wrong */
  0x41, /* LATIN CAPITAL LETTER A WITH OGONEK */
  0xA2, /* BREVE */
  0x4C, /* LATIN CAPITAL LETTER L WITH STROKE */
  0xA4, /* CURRENCY SIGN */
  0x4C, /* LATIN CAPITAL LETTER L WITH CARON */
  0x53, /* LATIN CAPITAL LETTER S WITH ACUTE */
  0xA7, /* SECTION SIGN */
  0xA8, /* DIAERESIS */
  0x53, /* LATIN CAPITAL LETTER S WITH CARON */
  0x53, /* LATIN CAPITAL LETTER S WITH CEDILLA */
  0x54, /* LATIN CAPITAL LETTER T WITH CARON */
  0x5A, /* LATIN CAPITAL LETTER Z WITH ACUTE */
  0xAD, /* SOFT HYPHEN */
  0x5A, /* LATIN CAPITAL LETTER Z WITH CARON */
  0x5A, /* LATIN CAPITAL LETTER Z WITH DOT ABOVE */
  0xB0, /* DEGREE SIGN */
  0x41, /* LATIN SMALL LETTER A WITH OGONEK */
  0xB2, /* OGONEK */
  0x4C, /* LATIN SMALL LETTER L WITH STROKE */
  0xB4, /* ACUTE ACCENT */
  0x4C, /* LATIN SMALL LETTER L WITH CARON */
  0x53, /* LATIN SMALL LETTER S WITH ACUTE */
  0xB7, /* CARON */
  0xB8, /* CEDILLA */
  0x53, /* LATIN SMALL LETTER S WITH CARON */
  0x53, /* LATIN SMALL LETTER S WITH CEDILLA */
  0x54, /* LATIN SMALL LETTER T WITH CARON */
  0x5A, /* LATIN SMALL LETTER Z WITH ACUTE */
  0xBD, /* DOUBLE ACUTE ACCENT */
  0x5A, /* LATIN SMALL LETTER Z WITH CARON */
  0x5A, /* LATIN SMALL LETTER Z WITH DOT ABOVE */

  0x52, /* LATIN CAPITAL LETTER R WITH ACUTE */
  0x41, /* LATIN CAPITAL LETTER A WITH ACUTE */
  0x41, /* LATIN CAPITAL LETTER A WITH CIRCUMFLEX */
  0x41, /* LATIN CAPITAL LETTER A WITH BREVE */
  0x41, /* LATIN CAPITAL LETTER A WITH DIAERESIS */
  0x4C, /* LATIN CAPITAL LETTER L WITH ACUTE */
  0x43, /* LATIN CAPITAL LETTER C WITH ACUTE */
  0x43, /* LATIN CAPITAL LETTER C WITH CEDILLA */
  0x43, /* LATIN CAPITAL LETTER C WITH CARON */
  0x45, /* LATIN CAPITAL LETTER E WITH ACUTE */
  0x45, /* LATIN CAPITAL LETTER E WITH OGONEK */
  0x45, /* LATIN CAPITAL LETTER E WITH DIAERESIS */
  0x45, /* LATIN CAPITAL LETTER E WITH CARON */
  0x49, /* LATIN CAPITAL LETTER I WITH ACUTE */
  0x49, /* LATIN CAPITAL LETTER I WITH CIRCUMFLEX */
  0x44, /* LATIN CAPITAL LETTER D WITH CARON */
  0x44, /* LATIN CAPITAL LETTER D WITH STROKE */
  0x4E, /* LATIN CAPITAL LETTER N WITH ACUTE */
  0x4E, /* LATIN CAPITAL LETTER N WITH CARON */
  0x4F, /* LATIN CAPITAL LETTER O WITH ACUTE */
  0x4F, /* LATIN CAPITAL LETTER O WITH CIRCUMFLEX */
  0x4F, /* LATIN CAPITAL LETTER O WITH DOUBLE ACUTE */
  0x4F, /* LATIN CAPITAL LETTER O WITH DIAERESIS */
  0xD7, /* MULTIPLICATION SIGN */
  0x52, /* LATIN CAPITAL LETTER R WITH CARON */
  0x55, /* LATIN CAPITAL LETTER U WITH RING ABOVE */
  0x55, /* LATIN CAPITAL LETTER U WITH ACUTE */
  0x55, /* LATIN CAPITAL LETTER U WITH DOUBLE ACUTE */
  0x55, /* LATIN CAPITAL LETTER U WITH DIAERESIS */
  0x59, /* LATIN CAPITAL LETTER Y WITH ACUTE */
  0x54, /* LATIN CAPITAL LETTER T WITH CEDILLA */
  0xDF, /* LATIN SMALL LETTER SHARP S */

  0x52, /* LATIN SMALL LETTER R WITH ACUTE */
  0x41, /* LATIN SMALL LETTER A WITH ACUTE */
  0x41, /* LATIN SMALL LETTER A WITH CIRCUMFLEX */
  0x41, /* LATIN SMALL LETTER A WITH BREVE */
  0x41, /* LATIN SMALL LETTER A WITH DIAERESIS */
  0x4C, /* LATIN SMALL LETTER L WITH ACUTE */
  0x43, /* LATIN SMALL LETTER C WITH ACUTE */
  0x43, /* LATIN SMALL LETTER C WITH CEDILLA */
  0x43, /* LATIN SMALL LETTER C WITH CARON */
  0x45, /* LATIN SMALL LETTER E WITH ACUTE */
  0x45, /* LATIN SMALL LETTER E WITH OGONEK */
  0x45, /* LATIN SMALL LETTER E WITH DIAERESIS */
  0x45, /* LATIN SMALL LETTER E WITH CARON */
  0x49, /* LATIN SMALL LETTER I WITH ACUTE */
  0x49, /* LATIN SMALL LETTER I WITH CIRCUMFLEX */
  0x44, /* LATIN SMALL LETTER D WITH CARON */
  0x44, /* LATIN SMALL LETTER D WITH STROKE */
  0x4E, /* LATIN SMALL LETTER N WITH ACUTE */
  0x4E, /* LATIN SMALL LETTER N WITH CARON */
  0x4F, /* LATIN SMALL LETTER O WITH ACUTE */
  0x4F, /* LATIN SMALL LETTER O WITH CIRCUMFLEX */
  0x4F, /* LATIN SMALL LETTER O WITH DOUBLE ACUTE */
  0x4F, /* LATIN SMALL LETTER O WITH DIAERESIS */
  0xF7, /* DIVISION SIGN */
  0x52, /* LATIN SMALL LETTER R WITH CARON */
  0x55, /* LATIN SMALL LETTER U WITH RING ABOVE */
  0x55, /* LATIN SMALL LETTER U WITH ACUTE */
  0x55, /* LATIN SMALL LETTER U WITH DOUBLE ACUTE */
  0x55, /* LATIN SMALL LETTER U WITH DIAERESIS */
  0x59, /* LATIN SMALL LETTER Y WITH ACUTE */
  0x54, /* LATIN SMALL LETTER T WITH CEDILLA */
  0xFF  /* DOT ABOVE */
};

///
/// PolishCollate2[]

// This table SHOULD NOT be used without changes in languages using ISO-8859-2
// encoding other than Polish. Collating order for accented characters is
// defined here as following:
//
// - character without accent,
// - Polish specific accented character (for Z order is Z WITH ACUTE, Z WITH DOT
//   ABOVE),
// - character with ring above (if exists),
// - character with acute (if exists and if not Polish specific),
// - character with double acute (if exists),
// - character with circumflex (if exists),
// - character with breve (if exists),
// - character with dieresis (if exists),
// - character with caron (if exists),
// - character with cedilla (if exists).
//
//  This order is probably not right for any language except Polish. [krashan]

const UBYTE PolishCollate2[256] =
{
  0x00, /* NULL */
  0x01, /* START OF HEADING */
  0x02, /* START OF TEXT */
  0x03, /* END OF TEXT */
  0x04, /* END OF TRANSMISSION */
  0x05, /* ENQUIRY */
  0x06, /* ACKNOWLEDGE */
  0x07, /* BELL */
  0x08, /* BACKSPACE */
  0x09, /* HORIZONTAL TABULATION */
  0x0A, /* LINE FEED */
  0x0B, /* VERTICAL TABULATION */
  0x0C, /* FORM FEED */
  0x0D, /* CARRIAGE RETURN */
  0x0E, /* SHIFT OUT */
  0x0F, /* SHIFT IN */
  0x10, /* DATA LINK ESCAPE */
  0x11, /* DEVICE CONTROL ONE */
  0x12, /* DEVICE CONTROL TWO */
  0x13, /* DEVICE CONTROL THREE */
  0x14, /* DEVICE CONTROL FOUR */
  0x15, /* NEGATIVE ACKNOWLEDGE */
  0x16, /* SYNCHRONOUS IDLE */
  0x17, /* END OF TRANSMISSION BLOCK */
  0x18, /* CANCEL */
  0x19, /* END OF MEDIUM */
  0x1A, /* SUBSTITUTE */
  0x1B, /* ESCAPE */
  0x1C, /* FILE SEPARATOR */
  0x1D, /* GROUP SEPARATOR */
  0x1E, /* RECORD SEPARATOR */
  0x1F, /* UNIT SEPARATOR */

  0x20, /* SPACE */
  0x21, /* EXCLAMATION MARK */
  0x22, /* QUOTATION MARK */
  0x23, /* NUMBER SIGN */
  0x24, /* DOLLAR SIGN */
  0x25, /* PERCENT SIGN */
  0x26, /* AMPERSAND */
  0x27, /* APOSTROPHE */
  0x28, /* LEFT PARENTHESIS */
  0x29, /* RIGHT PARENTHESIS */
  0x2A, /* ASTERISK */
  0x2B, /* PLUS SIGN */
  0x2C, /* COMMA */
  0x2D, /* HYPHEN-MINUS */
  0x2E, /* FULL STOP */
  0x2F, /* SOLIDUS */
  0x30, /* DIGIT ZERO */
  0x31, /* DIGIT ONE */
  0x32, /* DIGIT TWO */
  0x33, /* DIGIT THREE */
  0x34, /* DIGIT FOUR */
  0x35, /* DIGIT FIVE */
  0x36, /* DIGIT SIX */
  0x37, /* DIGIT SEVEN */
  0x38, /* DIGIT EIGHT */
  0x39, /* DIGIT NINE */
  0x3A, /* COLON */
  0x3B, /* SEMICOLON */
  0x3C, /* LESS-THAN SIGN */
  0x3D, /* EQUALS SIGN */
  0x3E, /* GREATER-THAN SIGN */
  0x3F, /* QUESTION MARK */

  0x40, /* COMMERCIAL AT */
  0x41, /* LATIN CAPITAL LETTER A */
  0x47, /* LATIN CAPITAL LETTER B */
  0x48, /* LATIN CAPITAL LETTER C */
  0x4C, /* LATIN CAPITAL LETTER D */
  0x4F, /* LATIN CAPITAL LETTER E */
  0x54, /* LATIN CAPITAL LETTER F */
  0x55, /* LATIN CAPITAL LETTER G */
  0x56, /* LATIN CAPITAL LETTER H */
  0x57, /* LATIN CAPITAL LETTER I */
  0x58, /* LATIN CAPITAL LETTER J */
  0x59, /* LATIN CAPITAL LETTER K */
  0x5A, /* LATIN CAPITAL LETTER L */
  0x5E, /* LATIN CAPITAL LETTER M */
  0x5F, /* LATIN CAPITAL LETTER N */
  0x62, /* LATIN CAPITAL LETTER O */
  0x67, /* LATIN CAPITAL LETTER P */
  0x68, /* LATIN CAPITAL LETTER Q */
  0x69, /* LATIN CAPITAL LETTER R */
  0x6C, /* LATIN CAPITAL LETTER S */
  0x70, /* LATIN CAPITAL LETTER T */
  0x73, /* LATIN CAPITAL LETTER U */
  0x78, /* LATIN CAPITAL LETTER V */
  0x79, /* LATIN CAPITAL LETTER W */
  0x7A, /* LATIN CAPITAL LETTER X */
  0x7B, /* LATIN CAPITAL LETTER Y */
  0x7D, /* LATIN CAPITAL LETTER Z */
  0x81, /* LEFT SQUARE BRACKET */
  0x82, /* REVERSE SOLIDUS */
  0x83, /* RIGHT SQUARE BRACKET */
  0x84, /* CIRCUMFLEX ACCENT */
  0x85, /* LOW LINE */

  0x60, /* GRAVE ACCENT */
  0x41, /* LATIN SMALL LETTER A */
  0x47, /* LATIN SMALL LETTER B */
  0x48, /* LATIN SMALL LETTER C */
  0x4C, /* LATIN SMALL LETTER D */
  0x4F, /* LATIN SMALL LETTER E */
  0x54, /* LATIN SMALL LETTER F */
  0x55, /* LATIN SMALL LETTER G */
  0x56, /* LATIN SMALL LETTER H */
  0x57, /* LATIN SMALL LETTER I */
  0x58, /* LATIN SMALL LETTER J */
  0x59, /* LATIN SMALL LETTER K */
  0x5A, /* LATIN SMALL LETTER L */
  0x5E, /* LATIN SMALL LETTER M */
  0x5F, /* LATIN SMALL LETTER N */
  0x62, /* LATIN SMALL LETTER O */
  0x67, /* LATIN SMALL LETTER P */
  0x68, /* LATIN SMALL LETTER Q */
  0x69, /* LATIN SMALL LETTER R */
  0x6C, /* LATIN SMALL LETTER S */
  0x70, /* LATIN SMALL LETTER T */
  0x73, /* LATIN SMALL LETTER U */
  0x78, /* LATIN SMALL LETTER V */
  0x79, /* LATIN SMALL LETTER W */
  0x7A, /* LATIN SMALL LETTER X */
  0x7B, /* LATIN SMALL LETTER Y */
  0x7D, /* LATIN SMALL LETTER Z */
  0x86, /* LEFT CURLY BRACKET */
  0x87, /* VERTICAL LINE */
  0x88, /* RIGHT CURLY BRACKET */
  0x89, /* TILDE */
  0x8A, /* DELETE */

  0x8B, /* <control> */
  0x8C, /* <control> */
  0x8D, /* <control> */
  0x8E, /* <control> */
  0x8F, /* <control> */
  0x90, /* <control> */
  0x91, /* <control> */
  0x92, /* <control> */
  0x93, /* <control> */
  0x94, /* <control> */
  0x95, /* <control> */
  0x96, /* <control> */
  0x97, /* <control> */
  0x98, /* <control> */
  0x99, /* <control> */
  0x9A, /* <control> */
  0x9B, /* <control> */
  0x9C, /* <control> */
  0x9D, /* <control> */
  0x9E, /* <control> */
  0x9F, /* <control> */
  0xA0, /* <control> */
  0xA1, /* <control> */
  0xA2, /* <control> */
  0xA3, /* <control> */
  0xA4, /* <control> */
  0xA5, /* <control> */
  0xA6, /* <control> */
  0xA7, /* <control> */
  0xA8, /* <control> */
  0xA9, /* <control> */
  0xAA, /* <control> */

  0x20, /* NO-BREAK SPACE */
  0x42, /* LATIN CAPITAL LETTER A WITH OGONEK */
  0xAB, /* BREVE */
  0x5B, /* LATIN CAPITAL LETTER L WITH STROKE */
  0xAC, /* CURRENCY SIGN */
  0x5D, /* LATIN CAPITAL LETTER L WITH CARON */
  0x6D, /* LATIN CAPITAL LETTER S WITH ACUTE */
  0xAD, /* SECTION SIGN */
  0xAE, /* DIAERESIS */
  0x6E, /* LATIN CAPITAL LETTER S WITH CARON */
  0x6F, /* LATIN CAPITAL LETTER S WITH CEDILLA */
  0x71, /* LATIN CAPITAL LETTER T WITH CARON */
  0x7E, /* LATIN CAPITAL LETTER Z WITH ACUTE */
  0xAF, /* SOFT HYPHEN */
  0x80, /* LATIN CAPITAL LETTER Z WITH CARON */
  0x7F, /* LATIN CAPITAL LETTER Z WITH DOT ABOVE */
  0xB0, /* DEGREE SIGN */
  0x42, /* LATIN SMALL LETTER A WITH OGONEK */
  0xB1, /* OGONEK */
  0x5B, /* LATIN SMALL LETTER L WITH STROKE */
  0xB2, /* ACUTE ACCENT */
  0x5D, /* LATIN SMALL LETTER L WITH CARON */
  0x6D, /* LATIN SMALL LETTER S WITH ACUTE */
  0xB3, /* CARON */
  0xB4, /* CEDILLA */
  0x6E, /* LATIN SMALL LETTER S WITH CARON */
  0x6F, /* LATIN SMALL LETTER S WITH CEDILLA */
  0x71, /* LATIN SMALL LETTER T WITH CARON */
  0x7E, /* LATIN SMALL LETTER Z WITH ACUTE */
  0xB5, /* DOUBLE ACUTE ACCENT */
  0x80, /* LATIN SMALL LETTER Z WITH CARON */
  0x7F, /* LATIN SMALL LETTER Z WITH DOT ABOVE */

  0x6A, /* LATIN CAPITAL LETTER R WITH ACUTE */
  0x43, /* LATIN CAPITAL LETTER A WITH ACUTE */
  0x44, /* LATIN CAPITAL LETTER A WITH CIRCUMFLEX */
  0x45, /* LATIN CAPITAL LETTER A WITH BREVE */
  0x46, /* LATIN CAPITAL LETTER A WITH DIAERESIS */
  0x5C, /* LATIN CAPITAL LETTER L WITH ACUTE */
  0x49, /* LATIN CAPITAL LETTER C WITH ACUTE */
  0x4A, /* LATIN CAPITAL LETTER C WITH CEDILLA */
  0x4B, /* LATIN CAPITAL LETTER C WITH CARON */
  0x51, /* LATIN CAPITAL LETTER E WITH ACUTE */
  0x50, /* LATIN CAPITAL LETTER E WITH OGONEK */
  0x52, /* LATIN CAPITAL LETTER E WITH DIAERESIS */
  0x53, /* LATIN CAPITAL LETTER E WITH CARON */
  0xCD, /* LATIN CAPITAL LETTER I WITH ACUTE */
  0xCE, /* LATIN CAPITAL LETTER I WITH CIRCUMFLEX */
  0x4D, /* LATIN CAPITAL LETTER D WITH CARON */
  0x4E, /* LATIN CAPITAL LETTER D WITH STROKE */
  0x60, /* LATIN CAPITAL LETTER N WITH ACUTE */
  0x61, /* LATIN CAPITAL LETTER N WITH CARON */
  0x63, /* LATIN CAPITAL LETTER O WITH ACUTE */
  0x64, /* LATIN CAPITAL LETTER O WITH CIRCUMFLEX */
  0x65, /* LATIN CAPITAL LETTER O WITH DOUBLE ACUTE */
  0x66, /* LATIN CAPITAL LETTER O WITH DIAERESIS */
  0xB6, /* MULTIPLICATION SIGN */
  0x6B, /* LATIN CAPITAL LETTER R WITH CARON */
  0x74, /* LATIN CAPITAL LETTER U WITH RING ABOVE */
  0x75, /* LATIN CAPITAL LETTER U WITH ACUTE */
  0x76, /* LATIN CAPITAL LETTER U WITH DOUBLE ACUTE */
  0x77, /* LATIN CAPITAL LETTER U WITH DIAERESIS */
  0x7C, /* LATIN CAPITAL LETTER Y WITH ACUTE */
  0x72, /* LATIN CAPITAL LETTER T WITH CEDILLA */
  0xB7, /* LATIN SMALL LETTER SHARP S */

  0x6A, /* LATIN SMALL LETTER R WITH ACUTE */
  0x43, /* LATIN SMALL LETTER A WITH ACUTE */
  0x44, /* LATIN SMALL LETTER A WITH CIRCUMFLEX */
  0x45, /* LATIN SMALL LETTER A WITH BREVE */
  0x46, /* LATIN SMALL LETTER A WITH DIAERESIS */
  0x5C, /* LATIN SMALL LETTER L WITH ACUTE */
  0x49, /* LATIN SMALL LETTER C WITH ACUTE */
  0x4A, /* LATIN SMALL LETTER C WITH CEDILLA */
  0x4B, /* LATIN SMALL LETTER C WITH CARON */
  0x51, /* LATIN SMALL LETTER E WITH ACUTE */
  0x50, /* LATIN SMALL LETTER E WITH OGONEK */
  0x52, /* LATIN SMALL LETTER E WITH DIAERESIS */
  0x53, /* LATIN SMALL LETTER E WITH CARON */
  0xED, /* LATIN SMALL LETTER I WITH ACUTE */
  0xEE, /* LATIN SMALL LETTER I WITH CIRCUMFLEX */
  0x4D, /* LATIN SMALL LETTER D WITH CARON */
  0x4E, /* LATIN SMALL LETTER D WITH STROKE */
  0x60, /* LATIN SMALL LETTER N WITH ACUTE */
  0x61, /* LATIN SMALL LETTER N WITH CARON */
  0x63, /* LATIN SMALL LETTER O WITH ACUTE */
  0x64, /* LATIN SMALL LETTER O WITH CIRCUMFLEX */
  0x65, /* LATIN SMALL LETTER O WITH DOUBLE ACUTE */
  0x66, /* LATIN SMALL LETTER O WITH DIAERESIS */
  0xB8, /* DIVISION SIGN */
  0x6B, /* LATIN SMALL LETTER R WITH CARON */
  0x74, /* LATIN SMALL LETTER U WITH RING ABOVE */
  0x75, /* LATIN SMALL LETTER U WITH ACUTE */
  0x76, /* LATIN SMALL LETTER U WITH DOUBLE ACUTE */
  0x77, /* LATIN SMALL LETTER U WITH DIAERESIS */
  0x7C, /* LATIN SMALL LETTER Y WITH ACUTE */
  0x72, /* LATIN SMALL LETTER T WITH CEDILLA */
  0xB9  /* DOT ABOVE */
};

///
