/*
    Copyright  1995-2001, The AROS Development Team. All rights reserved.
    $Id: opencataloga.c,v 1.18 2011/08/07 17:41:48 itix Exp $

    Desc:
    Lang: english
*/
#define AROS_ALMOST_COMPATIBLE

#include <string.h>

#include <exec/lists.h>
#include <proto/exec.h>
#include <proto/dos.h>
#include <libraries/iffparse.h>
#include <proto/iffparse.h>
#include <proto/utility.h>

#include "locale_intern.h"

#include <aros/debug.h>

#define	DEBUG_OPENCATALOG(x)	;

ULONG ConvertUTF8ToUCS4(CONST_STRPTR src, WSTRPTR dst, LONG maxlen);
ULONG ConvertUCS4ToUTF8(CONST_WSTRPTR src, STRPTR dst, LONG maxlen);

static BOOL convert_noconv(struct LocaleBase *LocaleBase, struct IntCatalog *catalog)
{
	UBYTE *buffer = catalog->ic_StringChunk;
	ULONG i, strlen, id, previd = 0;
	BOOL  inorder = TRUE;
	STRPTR str = NULL;

	for (i = 0; i < catalog->ic_NumStrings; i++)
	{
		id = (buffer[0] << 24) + (buffer[1] << 16) + (buffer[2] << 8) + (buffer[3]);
		strlen = (buffer[4] << 24) + (buffer[5] << 16) + (buffer[6] << 8) + (buffer[7]);

		str = AllocPooled(catalog->ic_MemPool, strlen + 1);

		if (!str)
			break;

		bcopy(&buffer[8], str, strlen);

		str[strlen] = '\0';

		catalog->ic_CatStrings[i].cs_String = str;
		catalog->ic_CatStrings[i].cs_Id = id;

		//DEBUG_OPENCATALOG(dprintf(""OpenCatalogA: ID_STRS Catalog String #%d id=%d string=\"%s\"\n", i, id, catalog->ic_CatStrings[i].cs_String));

		strlen  = 8 + strlen + (strlen & 1);
		if (strlen & 3) strlen += 4 - (strlen & 3);

		if (id < previd) inorder = FALSE;

		buffer += strlen;
		previd = id;
	}

	if (inorder) catalog->ic_Flags |= ICF_INORDER;

	return str ? TRUE : FALSE;
}

ULONG UTF8_Decode(CONST_STRPTR utf8, WCHAR *utf32);
ULONG UTF8_Encode(WCHAR utf32, STRPTR utf8);

static ULONG examine_utf8_to_latin1(CONST_STRPTR latin1, ULONG *need_conv)
{
	ULONG len = 1, conv = 0;
	UBYTE *src = (UBYTE *)latin1;

	for (;;)
	{
		ULONG octets;
		WCHAR ucs4;

		octets = UTF8_Decode(src, &ucs4);

		if (!octets)
			break;

		if (octets > 1)
			conv = 1;

		len += octets;
		src += octets;
	}

	*need_conv = conv;

	return len;
}

static void utf8_to_latin1(CONST_STRPTR utf8, STRPTR latin1)
{
	ULONG octets, c;

	do
	{
		WCHAR utf32;

		octets = UTF8_Decode(utf8, &utf32);

		c = utf32;

		if (c > 0xff)
			c = '?';

		*latin1++ = c;

		utf8 += octets;
	}
	while (c && octets);
}

static ULONG examine_latin1_to_utf8(CONST_STRPTR _src, ULONG *need_conv)
{
	ULONG len = 1, conv = 0, octets;
	UBYTE *src = (UBYTE *)_src;

	do
	{
		TEXT dummy[4];

		octets = UTF8_Encode(*src++, (STRPTR)&dummy);

		if (octets > 1)
			conv = 1;

		len += octets;
	}
	while (octets);

	*need_conv = conv;

	return len;
}

static ULONG examine_utf32_to_utf8(CONST_WSTRPTR src)
{
	ULONG octets, len = 1;

	do
	{
		TEXT dummy[4];

		octets = UTF8_Encode(*src++, (STRPTR)&dummy);

		len += octets;
	}
	while (octets);

	return len;
}

static BOOL convert_from_utf8(struct LocaleBase *LocaleBase, struct IntCatalog *catalog, BOOL utf32)
{
	UBYTE *buffer = catalog->ic_StringChunk;
	ULONG i, strlen, id, previd = 0;
	BOOL  inorder = TRUE;
	APTR  string;

	string = NULL;

	for (i = 0; i < catalog->ic_NumStrings; i++)
	{
		STRPTR s;
		ULONG newlen, conv;

		id = (buffer[0] << 24) + (buffer[1] << 16) + (buffer[2] << 8) + (buffer[3]);
		strlen = (buffer[4] << 24) + (buffer[5] << 16) + (buffer[6] << 8) + (buffer[7]);

		s = &buffer[8];
		newlen = examine_utf8_to_latin1(s, &conv);

		string = AllocPooled(catalog->ic_MemPool, newlen * (utf32 ? 4 : 1));

		if (!string)
			break;

		if (utf32)
		{
			ConvertUTF8ToUCS4(s, string, -1);
		}
		else
		{
			if (!conv)
				strcpy(string, s);
			else
				utf8_to_latin1(s, string);
		}

		catalog->ic_CatStrings[i].cs_String = string;
		catalog->ic_CatStrings[i].cs_Id = id;

		//DEBUG_OPENCATALOG(dprintf(""OpenCatalogA: ID_STRS Catalog String #%d id=%d string=\"%s\"\n", i, id, catalog->ic_CatStrings[i].cs_String));

		strlen  = 8 + strlen + (strlen & 1);
		if (strlen & 3) strlen += 4 - (strlen & 3);

		if (id < previd) inorder = FALSE;

		buffer += strlen;
		previd = id;
	}

	if (inorder) catalog->ic_Flags |= ICF_INORDER;

	return string ? TRUE : FALSE;
}

static void latin1_to_utf8(CONST_STRPTR _src, STRPTR dst)
{
	ULONG octets;
	UBYTE *src = (UBYTE *)_src;

	do
	{
		octets = UTF8_Encode(*src++, dst);
		dst += octets;
	}
	while (octets);
}

static BOOL convert_from_utf32(struct LocaleBase *LocaleBase, struct IntCatalog *catalog, BOOL utf8)
{
	UBYTE *buffer = catalog->ic_StringChunk;
	ULONG i, strlen, id, previd = 0;
	BOOL  inorder = TRUE;
	APTR  string;

	string = NULL;

	for (i = 0; i < catalog->ic_NumStrings; i++)
	{
		UBYTE *s;
		ULONG utflen;

		id = (buffer[0] << 24) + (buffer[1] << 16) + (buffer[2] << 8) + (buffer[3]);
		strlen = (buffer[4] << 24) + (buffer[5] << 16) + (buffer[6] << 8) + (buffer[7]);

		s = &buffer[8];

		if (utf8)
			utflen = examine_utf32_to_utf8((CONST_WSTRPTR)s);
		else
			utflen = strlen + 1;

		string = AllocPooled(catalog->ic_MemPool, utflen);

		if (!string)
			break;

		if (utf8)
		{
			ConvertUCS4ToUTF8((CONST_WSTRPTR)s, string, -1);
		}
		else
		{
			UBYTE *dst = string;

			while (utflen > 1)
			{
				*dst++ = *s++;
				utflen--;
			}

			*dst = '\0';
		}

		catalog->ic_CatStrings[i].cs_String = string;
		catalog->ic_CatStrings[i].cs_Id = id;

		//DEBUG_OPENCATALOG(dprintf(""OpenCatalogA: ID_STRS Catalog String #%d id=%d string=\"%s\"\n", i, id, catalog->ic_CatStrings[i].cs_String));

		strlen  = 8 + strlen + (strlen & 1);
		if (strlen & 3) strlen += 4 - (strlen & 3);

		if (id < previd) inorder = FALSE;

		buffer += strlen;
		previd = id;
	}

	if (inorder) catalog->ic_Flags |= ICF_INORDER;

	return string ? TRUE : FALSE;
}

static BOOL convert_from_latin1(struct LocaleBase *LocaleBase, struct IntCatalog *catalog, BOOL utf32)
{
	UBYTE *buffer = catalog->ic_StringChunk;
	ULONG i, strlen, id, previd = 0;
	BOOL  inorder = TRUE;
	APTR  string;

	string = NULL;

	for (i = 0; i < catalog->ic_NumStrings; i++)
	{
		UBYTE *s;
		ULONG utflen, conv;

		id = (buffer[0] << 24) + (buffer[1] << 16) + (buffer[2] << 8) + (buffer[3]);
		strlen = (buffer[4] << 24) + (buffer[5] << 16) + (buffer[6] << 8) + (buffer[7]);

		s = &buffer[8];

		if (utf32)
			utflen = strlen + 1;
		else
			utflen = examine_latin1_to_utf8(s, &conv);

		string = AllocPooled(catalog->ic_MemPool, utflen * (utf32 ? 4 : 1));

		if (!string)
			break;

		if (utf32)
		{
			ULONG *p = (ULONG *)string;

			while (utflen > 1)
			{
				*p++ = *s++;
				utflen--; 
			}

			*p = 0;
		}
		else
		{
			if (!conv)
			{
				strcpy(string, s);
			}
			else
			{
				latin1_to_utf8(s, string);
			}
		}

		catalog->ic_CatStrings[i].cs_String = string;
		catalog->ic_CatStrings[i].cs_Id = id;

		//DEBUG_OPENCATALOG(dprintf(""OpenCatalogA: ID_STRS Catalog String #%d id=%d string=\"%s\"\n", i, id, catalog->ic_CatStrings[i].cs_String));

		strlen  = 8 + strlen + (strlen & 1);
		if (strlen & 3) strlen += 4 - (strlen & 3);

		if (id < previd) inorder = FALSE;

		buffer += strlen;
		previd = id;
	}

	if (inorder) catalog->ic_Flags |= ICF_INORDER;

	return string ? TRUE : FALSE;
}

static BOOL convert_strings(struct LocaleBase *LocaleBase, struct IntCatalog *catalog, ULONG sourcecodeset, ULONG destcodeset)
{
	BOOL rc = FALSE;

	/* Fill out catalog->ic_CatStrings array */

	if (sourcecodeset == CODESET_LATIN1 && destcodeset != CODESET_LATIN1)
	{
		rc = convert_from_latin1(LocaleBase, catalog, destcodeset == CODESET_UTF32);
	}
	else if (sourcecodeset == CODESET_UTF8 && destcodeset != CODESET_UTF8)
	{
		rc = convert_from_utf8(LocaleBase, catalog, destcodeset == CODESET_UTF32);
	}
	else if (sourcecodeset == CODESET_UTF32 && destcodeset != CODESET_UTF32)
	{
		rc = convert_from_utf32(LocaleBase, catalog, destcodeset == CODESET_UTF8);
	}
	else
	{
		rc = convert_noconv(LocaleBase, catalog);
	}

	return rc;
}

/*****************************************************************************

    NAME */
#include <proto/locale.h>

	AROS_LH3(struct Catalog *, OpenCatalogA,

/*  SYNOPSIS */
	AROS_LHA(struct Locale  *, locale, A0),
	AROS_LHA(STRPTR          , name, A1),
	AROS_LHA(struct TagItem *, tags, A2),

/*  LOCATION */
	struct LocaleBase *, LocaleBase, 25, Locale)

/* ---- locale.library/OpenCatalogA
 *
 *   Name
 *        OpenCatalogA --
 *
 *   FUNCTION
 *
 *   INPUTS
 *
 *   RESULT
 *
 *   NOTES
 *
 *   EXAMPLE
 *
 *   BUGS
 *
 *   SEE ALSO
 *
 * ----
 *
 *   INTERNALS
 *
 *   HISTORY
 *   27-11-96   digulla automatically created from
 *              locale_lib.fd and clib/locale_protos.h
 */
/*****************************************************************************/
{
	AROS_LIBFUNC_INIT
	AROS_LIBBASE_EXT_DECL(struct Library *,LocaleBase)

	struct Locale     *def_locale = NULL;
	struct IntCatalog *catalog = NULL;
	char              *language;
	char              *app_language;
	char              *specific_language;
	struct Process    *MyProcess;
#define FILENAMESIZE 256
	char   filename[FILENAMESIZE];
	char   buf[100];
	LONG   chars;
	ULONG  version;
	ULONG  catversion, catrevision;
	WORD   pref_language;
	UWORD  i;
	ULONG  codeset;
	ULONG  systemcatalog = GetTagData(OC_SystemCatalog, FALSE, tags); /* System catalogs are exclusively loaded from MOSSYS: only. */

	DEBUG_OPENCATALOG(dprintf("OpenCatalogA: locale 0x%lx name <%s> Tags 0x%lx localebase 0x%lx\n", locale, name, tags, LocaleBase));

	/* Clear error condition before we start. */
	SetIoErr(0);

	if (!locale)
	{
		DEBUG_OPENCATALOG(dprintf("OpenCatalogA: no locale, use default locale\n"));
		locale = def_locale = OpenLocale(NULL);
		DEBUG_OPENCATALOG(dprintf("OpenCatalogA: def_locale 0x%lx\n", def_locale));
	}

	if (!locale)
	{
		DEBUG_OPENCATALOG(dprintf("OpenCatalogA: nolocale..done\n"));
		return NULL;
	}

	MyProcess = (struct Process *) FindTask(NULL);

	specific_language = (char *)GetTagData(OC_Language, (IPTR)0, tags);

	DEBUG_OPENCATALOG(dprintf("OpenCatalogA: specific lang 0x%lx \"%s\"\n",specific_language,specific_language ? specific_language : "<NULL>"));
	if (specific_language)
	{
		language = specific_language;
		pref_language = -1;
		DEBUG_OPENCATALOG(dprintf("OpenCatalogA: language 0x%lx \"%s\"\n",language,language));
	}
	else
	{
		language = locale->loc_PrefLanguages[0];
		pref_language = 0;
		DEBUG_OPENCATALOG(dprintf("OpenCatalogA: language 0x%lx \"%s\"\n",language,language));
	}

	if (!language)
	{
		if (def_locale) 
		{
			CloseLocale(def_locale);
		}

		DEBUG_OPENCATALOG(dprintf("OpenCatalogA: no language.. return NULL\n"));
		return NULL;
	}

	/*
	 * Check whether the built in language of the application matches
	 * the language of the default locale. If it matches, then I
	 * don't need to load anything.
	 */
	app_language = (char *)GetTagData(OC_BuiltInLanguage,
	                                  (IPTR)defLocale.loc_PrefLanguages[0],  /* This struct is const, value equals "english", simply avoiding dupe strings. */
	                                  tags);

	DEBUG_OPENCATALOG(dprintf("OpenCatalogA: app_language 0x%lx \"%s\"\n", app_language, app_language));

	/*
	 * Note: strcmp() here, not Stricmp(). - Piru
	 */
	if (app_language && !strcmp(app_language, language))
	{
		if (def_locale) 
		{
			CloseLocale(def_locale);
		}

		DEBUG_OPENCATALOG(dprintf("OpenCatalogA: use built-in language, return NULL\n"));
		return NULL;
	}

	version = GetTagData(OC_Version, 0, tags);
	DEBUG_OPENCATALOG(dprintf("OpenCatalogA: version %ld\n",version));

	codeset = GetTagData(OC_CodeSet, CODESET_LATIN1, tags);

	if (codeset >= CODESET_COUNT)
	{
		codeset = CODESET_LATIN1;
	}

	if (name)
	{
		struct IFFHandle * iff = NULL;

		/*
		 * The wanted catalog might be in the list of catalogs that are
		 * already loaded. So check that list first.
		 */

		DEBUG_OPENCATALOG(dprintf("OpenCatalogA: CatalogLock 0x%lx\n", &IntLB(LocaleBase)->lb_CatalogLock));

		ObtainSemaphore(&IntLB(LocaleBase)->lb_CatalogLock);

		DEBUG_OPENCATALOG(dprintf("OpenCatalogA: search cached Catalog, name \"%s\", language \"%s\"\n", name, language))

		ForeachNode(&IntLB(LocaleBase)->lb_CatalogList, (struct Node *)catalog)
		{
			/*
			 * 27-mar-2003 bugfix
			 * Note: Stricmp() here, not strcmp()! This fixed the problems with
			 * franais catalogs, for example. Also added the missing version
			 * check. - Piru
			 */
			if ((catalog->ic_Catalog.cat_CodeSet == codeset && catalog->ic_Name) &&
			    (!Stricmp(catalog->ic_Name, name))                               &&
			    (version == 0 || (catalog->ic_Catalog.cat_Version == version))   &&
			    (catalog->ic_Catalog.cat_Language)                               &&
			    (!Stricmp(catalog->ic_Catalog.cat_Language, language)))
			{
				DEBUG_OPENCATALOG(dprintf("OpenCatalogA: found Catalog 0x%lx ic_Name \"%s\" cat_Language \"%s\"\n", catalog, catalog->ic_Name, catalog->ic_Catalog.cat_Language));
				catalog->ic_UseCount++;
				ReleaseSemaphore(&IntLB(LocaleBase)->lb_CatalogLock);

				if (def_locale)
				{
					CloseLocale(def_locale);
				}

				SetIoErr(ERROR_ACTION_NOT_KNOWN);

				DEBUG_OPENCATALOG(dprintf("OpenCatalogA: return Catalog 0x%lx\n",catalog));
				return (struct Catalog *)catalog;

			}

		} /* foreachnode */

		DEBUG_OPENCATALOG(dprintf("OpenCatalogA: found none\n"));
		ReleaseSemaphore(&IntLB(LocaleBase)->lb_CatalogLock);

		iff = AllocIFF();

		DEBUG_OPENCATALOG(dprintf("OpenCatalogA: iff 0x%lx\n",iff));
		if (!iff)
		{
			if (def_locale) 
			{
				CloseLocale(def_locale);
			}
			
			SetIoErr(ERROR_NO_FREE_STORE);

			DEBUG_OPENCATALOG(dprintf("OpenCatalogA: no iff, return NULL\n"));
			return NULL;
		}

		DEBUG_OPENCATALOG(dprintf("OpenCatalogA: pref_language %ld language 0x%lx \"%s\"\n", pref_language, language, language));

		while ((pref_language < 10) && language)
		{
			if (app_language && !strcmp(app_language, language))
			{
				FreeIFF(iff);

				if (def_locale) 
				{
					CloseLocale(def_locale);
				}

				SetIoErr(0);
				return NULL;
			}

			if (!systemcatalog)
			{
				if (MyProcess->pr_HomeDir)
				{
					DEBUG_OPENCATALOG(dprintf("OpenCatalogA: HomeDir !=NULL..try progdir\n"));
					strcpy(filename, "PROGDIR:Catalogs");
					DEBUG_OPENCATALOG(dprintf("OpenCatalogA: filename <%s>\n",filename));
					AddPart(filename, language, FILENAMESIZE);
					DEBUG_OPENCATALOG(dprintf("OpenCatalogA: filename <%s>\n",filename));
					AddPart(filename, name    , FILENAMESIZE);

					DEBUG_OPENCATALOG(dprintf("OpenCatalogA: filename <%s>\n",filename));
					iff->iff_Stream = (IPTR)Open(filename, MODE_OLDFILE);
					DEBUG_OPENCATALOG(dprintf("OpenCatalogA: iffstream 0x%lx\n", iff->iff_Stream));
				}

				if (iff->iff_Stream) 
				{
					break;
				}
			}

			{
				strcpy(filename, "MOSSYS:LOCALE/Catalogs");

				DEBUG_OPENCATALOG(dprintf("OpenCatalogA: filename <%s>\n",filename));
				AddPart(filename, language, FILENAMESIZE);
				DEBUG_OPENCATALOG(dprintf("OpenCatalogA: filename <%s>\n",filename));
				AddPart(filename, name    , FILENAMESIZE);

				DEBUG_OPENCATALOG(dprintf("OpenCatalogA: try filename <%s>\n",filename));

				{
					APTR oldwinptr = MyProcess->pr_WindowPtr;

					MyProcess->pr_WindowPtr = (APTR)-1;
					iff->iff_Stream = (IPTR)Open(filename, MODE_OLDFILE);
					MyProcess->pr_WindowPtr = oldwinptr;
				}

				if (iff->iff_Stream) 
				{
					break;
				}
			}

			if (!systemcatalog)
			{
				strcpy(filename, "LOCALE:Catalogs");

				DEBUG_OPENCATALOG(dprintf("OpenCatalogA: filename <%s>\n",filename));
				AddPart(filename, language, FILENAMESIZE);
				DEBUG_OPENCATALOG(dprintf("OpenCatalogA: filename <%s>\n",filename));
				AddPart(filename, name    , FILENAMESIZE);

				DEBUG_OPENCATALOG(dprintf("OpenCatalogA: try filename <%s>\n",filename));

				iff->iff_Stream = (IPTR)Open(filename, MODE_OLDFILE);

				if (iff->iff_Stream) 
				{
					break;
				}
			}

			pref_language++;
			language = locale->loc_PrefLanguages[pref_language];

		} /* while (pref_language < 10 && language) */

		DEBUG_OPENCATALOG(dprintf("OpenCatalogA: language 0x%lx \"%s\"\n",language,language ? language : "<NULL>"));

		/* We no longer need the locale. So close it if we opened it 
		 */

		if (def_locale)
		{
			CloseLocale(def_locale);
			def_locale = NULL;
		}

	#undef FILENAMESIZE

		if (!iff->iff_Stream)
		{
			DEBUG_OPENCATALOG(dprintf("OpenCatalogA: no stream, return NULL\n"));
			FreeIFF(iff);
			SetIoErr(ERROR_OBJECT_NOT_FOUND);
			return NULL;
		}

		DEBUG_OPENCATALOG(dprintf("OpenCatalogA: catalog name <%s>\n",name));
		catalog = AllocVec(sizeof(struct IntCatalog) + strlen(name) + 1, MEMF_CLEAR | MEMF_PUBLIC);
		DEBUG_OPENCATALOG(dprintf("OpenCatalogA: catalog 0x%lx\n",catalog));
		if (!catalog)
		{
			DEBUG_OPENCATALOG(dprintf("OpenCatalogA: no memory for catalog, return NULL\n"));
			Close((BPTR)iff->iff_Stream);
			FreeIFF(iff);
			SetIoErr(ERROR_NO_FREE_STORE);
			return NULL;
		}

		catalog->ic_UseCount = 1;
		catalog->ic_Catalog.cat_Link.ln_Name = catalog->ic_Name;
		catalog->ic_Catalog.cat_Language = catalog->ic_LanguageName;
		catalog->ic_Catalog.cat_CodeSet = codeset;
		strcpy(catalog->ic_Name, name);

		InitIFFasDOS(iff);

		if (!OpenIFF(iff, IFFF_READ))
		{
			ULONG catcodeset = CODESET_LATIN1;

			while (1)
			{
				LONG error = ParseIFF(iff, IFFPARSE_STEP);

				if (error == IFFERR_EOF)
				{
					ULONG rc;

					DEBUG_OPENCATALOG(dprintf("OpenCatalogA: parsed catalog\n"));

					if (!catalog->ic_StringChunk || !catalog->ic_MemPool)
					{
						error = 1;
						break;
					}

					rc = convert_strings(LocaleBase, catalog, catcodeset, codeset);

					FreeVec(catalog->ic_StringChunk);
					catalog->ic_StringChunk = NULL;

					if (!rc)
					{
						error = ERROR_NO_FREE_STORE;
						SetIoErr(ERROR_NO_FREE_STORE);
						break;
					}

					/*  Did everything go fine? 
					 */

					if (catalog->ic_LanguageName[0] == '\0')
					{
						/*  No ID_LANG chunk found. So setup languagename ourselves.
						 *  Hmm ... maybe this should be done anyway always. Because
						 *  if the catalog file *does* contain an ID_LANG chunk then
						 *  this should be the same as "language" anyway. And if it
						 *  is not, then maybe OpenCatalogA() should fail :-\ 
						 */

						strcpy(catalog->ic_LanguageName, language);
					}

					DEBUG_OPENCATALOG(dprintf("OpenCatalogA: Adding catalog language \"%s\"\n", catalog->ic_Catalog.cat_Language));

					/* Connect this catalog to the list of catalogs 
					 */
					ObtainSemaphore(&IntLB(LocaleBase)->lb_CatalogLock);
					ADDHEAD((struct List *)&IntLB(LocaleBase)->lb_CatalogList, &catalog->ic_Catalog.cat_Link);
					ReleaseSemaphore(&IntLB(LocaleBase)->lb_CatalogLock);

					CloseIFF(iff);
					Close((BPTR)iff->iff_Stream);
					FreeIFF(iff);

					DEBUG_OPENCATALOG(dprintf("OpenCatalogA: success, return catalog 0x%lx\n",catalog));
					return &catalog->ic_Catalog;

				} /* error == OFFERR_EOF */

				if (error == IFFERR_EOC) /* end of chunk */
				{
					continue;
				}

				if (error == 0)
				{
					struct ContextNode * top = CurrentChunk(iff);

					switch (top->cn_ID)
					{
						case ID_FORM:
							DEBUG_OPENCATALOG(dprintf("OpenCatalogA: ID_FORM\n"));
							break;

						case ID_FVER:
							DEBUG_OPENCATALOG(dprintf("OpenCatalogA: ID_FVER\n"));

							if (top->cn_Size > 100) 
							{
								break; /*max 100 bytes*/
							}

							error = ReadChunkBytes(iff, buf, top->cn_Size);

							if (error == top->cn_Size)
							{
								error = 0;
							}
							else
							{
								DEBUG_OPENCATALOG(dprintf("OpenCatalogA: ID_FVER ReadChunkBytes failed\n"));
								break;
							}

							buf[99] = 0;

							DEBUG_OPENCATALOG(dprintf("OpenCatalogA: ID_FVER verstring \"%s\"\n", buf));

							/*  Ok now we want to get the version and the revision.
							 *  They are separated by a blank space
							 */
							i = 0;

							while (buf[i] && (buf[i] != ' '))
							{
								i++;
							}

							while (buf[i] && (buf[i] == ' '))
							{
								i++;
							}

							while (buf[i] && (buf[i] != ' '))
							{
								i++;
							}

							DEBUG_OPENCATALOG(dprintf("OpenCatalogA: ID_FVER version \"%s\"\n", &buf[i]));

							if (buf[i])
							{
								if ((chars = StrToLong(&buf[i],(LONG *)&catversion)) < 0)
								{
									break;
								}

								DEBUG_OPENCATALOG(dprintf("OpenCatalogA: ID_FVER catversion %ld\n", catversion));

								i += chars;
								if (buf[i++])
								{
								    if (StrToLong(&buf[i],(LONG *)&catrevision) < 0)
									{
										break;
									}
								}

								DEBUG_OPENCATALOG(dprintf("OpenCatalogA: ID_FVER catrevision %ld\n", catrevision));

								catalog->ic_Catalog.cat_Version  = catversion;
								catalog->ic_Catalog.cat_Revision = catrevision;

								if (version != 0 && (catversion != version))
								{
									DEBUG_OPENCATALOG(dprintf("OpenCatalogA: ID_FVER wrong version (%ld != %ld), RETURN_ERROR\n", catversion, version));
									error = RETURN_ERROR;
								}
							}
							/*
							 * 27-mar-2003 bugfix
							 * This break was located inside the above closing bracket.
							 * That caused the routine to drop into ID_LANG if version
							 * wasn't properly parsed. - Piru
							 *
							 * 07-nov-2007 note
							 * With a proper intendation this would never have happened.
							 * Bad bad AROS coding style. - tokai
							 */
							break;

						case ID_LANG:
							DEBUG_OPENCATALOG(dprintf("OpenCatalogA: ID_LANG\n"));

							/* The IntCatalog structure has only 30 bytes reserved for
							 * the language name. So make sure the chunk is not bigger.
							 */

							if (top->cn_Size > 30) 
							{
								break;
							}

							error = ReadChunkBytes(iff, catalog->ic_LanguageName, top->cn_Size);
							if (error == top->cn_Size)
							{
								error = 0;
							}
							DEBUG_OPENCATALOG(dprintf("OpenCatalogA: ID_LANG catalog->ic_LanguageName \"%s\"\n", catalog->ic_LanguageName));

							break;

						case ID_CSET:
							DEBUG_OPENCATALOG(dprintf("OpenCatalogA: ID_CSET\n"));

							if (top->cn_Size == sizeof(struct CodeSet))
							{
								if (top->cn_Size == ReadChunkBytes(iff, &catalog->ic_CodeSet, top->cn_Size))
								{
									catcodeset = catalog->ic_CodeSet.cs_CodeSet;

									if (catcodeset >= CODESET_COUNT)
									{
										catcodeset = CODESET_LATIN1;
									}
								}
							}
							break;

						case ID_STRS:
							DEBUG_OPENCATALOG(dprintf("OpenCatalogA: ID_STRS\n"));

							if (!(catalog->ic_StringChunk = AllocVec(top->cn_Size, MEMF_ANY)) || !(catalog->ic_MemPool = CreatePool(MEMF_ANY, top->cn_Size, top->cn_Size)))
							{
								DEBUG_OPENCATALOG(dprintf("OpenCatalogA: ID_STRS AllocVec failed\n"));
								error = ERROR_NO_FREE_STORE;
								SetIoErr(error);
								break;
							}

							error = ReadChunkBytes(iff, catalog->ic_StringChunk, top->cn_Size);
							if (error == top->cn_Size)
							{
								error = 0;
							}
							else
							{
								DEBUG_OPENCATALOG(dprintf("OpenCatalogA: ID_STRS ReadChunkBytes failed\n"));
								break;
							}

							/* Count the number of strings 
							 */

							{
								UBYTE *buffer = catalog->ic_StringChunk;
								LONG   c      = 0, strlen;

								catalog->ic_NumStrings = 0;

								while (c < top->cn_Size)
								{
									catalog->ic_NumStrings++;

									strlen = (buffer[4] << 24) + (buffer[5] << 16) + (buffer[6] << 8) + (buffer[7]);
									strlen = 8 + strlen + (strlen & 1);

									if (strlen & 3) 
									{
										strlen += 4 - (strlen & 3);
									}

									c += strlen; buffer += strlen;
								}
							}

							if (catalog->ic_NumStrings == 0) 
							{
								break; /* Paranoia? */
							}

							if (!(catalog->ic_CatStrings = AllocPooled(catalog->ic_MemPool, catalog->ic_NumStrings * sizeof(struct CatStr))))
							{
								DEBUG_OPENCATALOG(dprintf("OpenCatalogA: ID_STRS AllocVec(2) failed\n"));
								error = ERROR_NO_FREE_STORE;
								SetIoErr(error);
								break;
							}
							break;

					} /* switch (top->cn_ID) */

				} /* if (error == 0) */

				if (error)
				{
					DEBUG_OPENCATALOG(dprintf("OpenCatalogA: Error occured, dispose catalog...\n"));

					dispose_catalog(catalog, LocaleBase);
					/*
					 * An error with the file occurred
					 */
					break;
				}

			} /* while (1) */

			CloseIFF(iff);

		} /* if (!OpenIFF(iff, IFFF_READ)) */

		Close((BPTR)iff->iff_Stream);
		FreeIFF(iff);
		FreeVec(catalog);

	} /* if (name) */

	if (def_locale) 
	{
		CloseLocale(def_locale);
	}

	DEBUG_OPENCATALOG(dprintf("OpenCatalogA: catalog not loaded, return NULL\n"));
	return NULL;

	AROS_LIBFUNC_EXIT

} /* OpenCatalogA */

